package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@("`0D````````````"`"L````!```````0'```````````0```````
M`,FP`````@!``#@`!@!``!D`&`````8````%`````````$```````!``0```
M````$`!``````````5`````````!4``````````(`````P````0````````!
MD```````$`&0```````0`9``````````%0`````````5``````````$````!
M````!0`````````````````0`````````!```````````%JL````````6JP`
M`````!````````$````'````````8````````"!@````````(&``````````
M9N````````!KV```````$````````@````8```````!@*```````(&`H````
M```@8"@````````"$`````````(0``````````@````$````!`````````&H
M```````0`:@``````!`!J``````````8`````````!@`````````!"]L:6)E
M>&5C+VQD+65L9BYS;RXQ``````````@````$`````49R965"4T0```V[S```
M`&$```!H`````````!X`````````.P`````````N````90```"4`````````
M`````$\`````````5````$T`````````-@```#T```!C````!````#````!7
M````7P```#@````````````````````@````4````"<```!6`````````"T`
M``!@````3@````T`````````8@```&0````J````9P`````````^````````
M`%,`````````50```%X```````````````@````?````%````"8````R````
M#````#H```!`````80```%P`````````10```#\`````````4@``````````
M``````````````!8````*P```!D```!+````+P```$(`````````````````
M```%````'0````<```!F````70```$,`````````(@````L`````````````
M``````!!`````````%D````1`````````$8```!'````````````````````
M``````````````````````,`````````````````````````````````````
M``````````````````````````\`````````````````````````````````
M`````````````````````````````````````````````!P`````````````
M```````;````"@```!,````````````````````6````#@```!``````````
M%P```"@`````````````````````````&@``````````````````````````
M````````````````````(P```!4````````````````````S````````````
M````````+``````````A````&````"D```!*`````````#4`````````3```
M`"0```!1````,0```````````````````````````````````#<````Y````
M!@```$@```!)````$@```%H```!$```````````````T````/````%L````)
M```````````````````````````````````````````=``````````````(`
M```````````````=``````````````,``````````````782```````````@
M8X`````````!G````\L2```+```````04<``````````$````]P2```+````
M```0'<``````````3`````P2```````````@8Z``````````0```!$$2````
M```````@8\``````````-````YD2```+```````0'```````````V````!82
M```````````@8^`````````'#````HL2```````````@9```````````)```
M`"$1```6```````@QN```````````0```B\2```````````@9"``````````
M;````#@@`````````````````````````````H`1```5```````@:R``````
M````"````$P2```,```````05B```````````````^D2```+```````04>``
M```````#2````_\2```+```````0-Z``````````8```!`T2```+```````0
M4.``````````Q````%(2```````````@9$`````````&!````%L1```6````
M```@QN@``````````0```&82```````````@9&`````````!0````'02````
M```````@9(``````````)```!",2```+```````00"`````````!7```!"\2
M```+```````0/^``````````)````(01```6```````@QO```````````0``
M`)(2```````````@9*`````````!4````L<2```````````@9,``````````
M+````P@2```````````@9.``````````*```!$H2```+```````008``````
M````;````E$1```6```````@QO0`````````!````X82```````````@90``
M````````+````R`2```````````@92``````````)````W<2```````````@
M94``````````7````*`1```6```````@QO@`````````"````V02````````
M```@96``````````)````*H2```````````@98``````````2````RX2````
M```````@9:``````````"````+42```````````@9<`````````$*````W\2
M```````````@9>``````````.````U,2```````````@9@``````````.```
M`,,1```6```````@QP``````````"````UL2```````````@9B``````````
M.````CD2```````````@9D``````````.````,D2```````````@9F``````
M````0````L$2```````````@9H``````````-````-<1```6```````@QP@`
M````````"````K(2```````````@9J`````````!F````.02```````````@
M9L`````````"!````C02```````````@9N``````````0````/01```6````
M```@QQ```````````0```/\2```````````@9P``````````X````1`2````
M```````@9R`````````,&````V,2```````````@9T``````````)````1\1
M```6```````@QQ@`````````"````S@2```````````@9V``````````)```
M`J02```````````@9X``````````)````IX2```````````@9Z``````````
M)```!%82```+```````054``````````*````JH2```````````@9\``````
M````:````2\2```````````@9^`````````#&````3T2```````````@:```
M```````B;````LX2```````````@:"``````````)````Q@2```````````@
M:$``````````?````O<2```````````@:&``````````*````Y00`/_Q````
M```@QN```````````````4L1```6```````@R]``````````"````5,2````
M```````@:(`````````!(````G@2```````````@:*`````````<E````C\2
M```````````@:,``````````4````KD2```````````@:.``````````%```
M`G$2```````````@:0`````````"%````5\1```6```````@QR``````````
M"```!%X2```+```````0.```````````)````E\1```6```````@QR@`````
M````0````VD2```````````@:2``````````@````Z`0`/_Q```````@R]@`
M`````````````M42```````````@:4``````````)````R<2```````````@
M:6``````````W````6H2```````````@:8``````````4````N01```6````
M```@QV@`````````"````7T2```````````@::``````````I````8H1```6
M```````@QW```````````0```9<1```6```````@QW@`````````$P```LD2
M```````````@:<``````````6```!'H2```+```````01J`````````*,```
M`:82```````````@:>``````````,````XT0`/_Q```````@QN``````````
M`````!$2```````````@:@`````````(-````;$2```````````@:B``````
M```"]```!(<2```+```````0/0`````````!&```!)D2```+```````01*``
M```````![````;P2```````````@:D``````````%````MP2```````````@
M:F`````````"%````P\2```````````@:H``````````H````I01```6````
M```@QY``````````"````W`2```````````@:J``````````8````S\2````
M```````@:L``````````*```!*82```+```````0/B`````````!M```!+,2
M```+```````00@`````````"C```!%@2```*```````0&^``````````````
M`<L1```6```````@QY@`````````"````=42```````````@:N``````````
MI````>P2```````````@:P`````````);`!L:6)P97)L+G-O`'!E<FQ?9G)E
M90!P97)L7W!A<G-E`%!,7W!E<FQ?9&5S=')U8W1?;&5V96P`7TIV7U)E9VES
M=&5R0VQA<W-E<P!?9FEN:0!P97)L7W)U;@!03%]I;E]E=F%L`%!E<FQ?879?
M<VAI9G0`4&5R;%]G=E]F971C:'!V`%!,7V5X:71?9FQA9W,`4&5R;%]S=E]S
M971P=@!03%]C;VUP8W8`<&5R;%]A;&QO8P!097)L7V1O=6YW:6YD`%!,7V]P
M`%!E<FQ?<WES7W1E<FT`4$Q?979A;%]R;V]T`&)O;W1?1'EN84QO861E<@!0
M3%]T86EN=&5D`%!E<FQ?;F5W6%-?9FQA9W,`<&5R;%]C;VYS=')U8W0`4$Q?
M8W5R<W1A8VMI;F9O`%!E<FQ?879?9F5T8V@`<&5R;%]D97-T<G5C=`!E;G9I
M<F]N`%!E<FQ?;6=?<V5T`%!,7W1O<%]E;G8`4&5R;%]S869E<WES;6%L;&]C
M`%!E<FQ?;F5W4U9P=@!03%]D;U]U;F1U;7``4$Q?;65M;W)Y7W=R87``4&5R
M;%]C<F]A:P!097)L7VYE=UA3`%!E<FQ?<WES7VEN:70S`%!,7W!A<G-E<@!0
M97)L7W-A=F5?9&5S=')U8W1O<E]X`%!E<FQ?<W9?,G!V7V9L86=S`&QI8FTN
M<V\N-0!L:6)C<GEP="YS;RXU`&QI8G5T:6PN<V\N.0!L:6)T:'(N<V\N,P!O
M<&5N`')E860`8VQO<V4`7U]E<G)O<@!L:6)C+G-O+C<`7U]M8E]S8E]L:6UI
M=`!?7W-T86-K7V-H:U]G=6%R9`!M96UC<'D`<F5A;&QO8P!?7W!R;V=N86UE
M`')E861L:6YK`%]?<W1D97)R<`!R;61I<@!M:V1I<@!S=')N8VUP`'-T<FQE
M;@!O<&5N9&ER`&QS965K`&%T97AI=`!A8V-E<W,`9V5T<&ED`&UE;6UO=F4`
M7T-U<G)E;G12=6YE3&]C86QE`%]?<W1A8VM?8VAK7V9A:6P`<W1R=&]K`&-L
M;W-E9&ER`'-T<FYC<'D`=6YL:6YK`&UE;7-E=`!?:6YI=%]T;',`9V5T=6ED
M`%]?<W!A<F-?=71R87!?<V5T=7``9G!R:6YT9@!S<')I;G1F`&QS=&%T`'-T
M<G-T<@!S=')C;7``<F5A9&1I<@!S=')D=7``97AE8W9P`%]E9&%T80!?7V)S
M<U]S=&%R=`!?96YD`"]U<W(O;&]C86PO;&EB+W!E<FPU+S4N,30N,B]M86-H
M+T-/4D4`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`6%-?26YT97)N
M86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P
M<F]C`'!A<E]D:7)N86UE`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A
M<E]C;&5A;G5P`'AS7VEN:70`6%-?26YT97)N86QS7U!!4E]#3$5!4E-404-+
M`'!A<E]M:W1M<&1I<@!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`
M<&%R7VEN:71?96YV`&UA:6X`1D)31%\Q+C``1D)31'!R:79A=&5?,2XP````
M`````````@`!``$````"``$````"`````P````$``0`!``$``0``````````
M``$``0```````@`"``$``@`"``(``@````(````"`````@`"`````@`#````
M`@````(````#``````````(````"``(``@`!``(```````(``@`"``$``0``
M``(``P`"``(````!``(``@`!``(``@````(``````````@`!`````0`"````
M`0`!`````@`"``(``@`$``$``0`!``````````````````$``0```B,````0
M````(`=Z*+`````#```$N````````0`"```"1P```!``````#Q[ZH`````0`
M``3!````$`=Z*+`````"```$N````````````"#&X`````L````3````````
M`````````"#&Z````!0````3`````````````````"#&\````!D````3````
M`````````````"#&]````!X````3`````````````````"#&^````"(````3
M`````````````````"#'`````"D````3`````````````````"#'"````"X`
M```3`````````````````"#'$````#(````3`````````````````"#'&```
M`#8````3`````````````````"#'(````$@````3`````````````````"#'
M*````$H````3`````````````````"#':````%`````3````````````````
M`"#'<````%(````3`````````````````"#'>````%,````3````````````
M`````"#'D````%\````3`````````````````"#'F````&4````3````````
M`````````"!C@`````,````5`````````````````"!CH`````8````5````
M`````````````"!CP`````<````5`````````````````"!CX`````D````5
M`````````````````"!D``````H````5`````````````````"!D(`````P`
M```5`````````````````"!D0````!,````5`````````````````"!D8```
M`!4````5`````````````````"!D@````!8````5`````````````````"!D
MH````!H````5`````````````````"!DP````!L````5````````````````
M`"!DX````!P````5`````````````````"!E`````!\````5````````````
M`````"!E(````"`````5`````````````````"!E0````"$````5````````
M`````````"!E8````",````5`````````````````"!E@````"0````5````
M`````````````"!EH````"4````5`````````````````"!EP````"8````5
M`````````````````"!EX````"<````5`````````````````"!F`````"@`
M```5`````````````````"!F(````"H````5`````````````````"!F0```
M`"L````5`````````````````"!F8````"P````5`````````````````"!F
M@````"T````5`````````````````"!FH````"\````5````````````````
M`"!FP````#`````5`````````````````"!FX````#$````5````````````
M`````"!G`````#,````5`````````````````"!G(````#0````5````````
M`````````"!G0````#4````5`````````````````"!G8````#<````5````
M`````````````"!G@````#@````5`````````````````"!GH````#D````5
M`````````````````"!GP````#L````5`````````````````"!GX````#P`
M```5`````````````````"!H`````#T````5`````````````````"!H(```
M`#X````5`````````````````"!H0````#\````5`````````````````"!H
M8````$`````5`````````````````"!H@````$,````5````````````````
M`"!HH````$0````5`````````````````"!HP````$4````5````````````
M`````"!HX````$8````5`````````````````"!I`````$<````5````````
M`````````"!I(````$L````5`````````````````"!I0````$T````5````
M`````````````"!I8````$X````5`````````````````"!I@````$\````5
M`````````````````"!IH````%$````5`````````````````"!IP````%0`
M```5`````````````````"!IX````%8````5`````````````````"!J````
M`%@````5`````````````````"!J(````%D````5`````````````````"!J
M0````%P````5`````````````````"!J8````%T````5````````````````
M`"!J@````%X````5`````````````````"!JH````&`````5````````````
M`````"!JP````&$````5`````````````````"!JX````&8````5````````
M`````````"!K`````&<````5``````````"=X[]`0```7P$```!```YU`0``
M`(''X`B!Z````````)WCOT#$!B`$A@8@$)`0`!FD!B`(HSB@`("@H`"#+'`#
M!0`(,J``P`$$0``5X'"CT,9>(`@"P,`2"0`(&L9Q(R#$",``A2B@&("@H``"
M0``,A@#@`84XH!C"62,@@*"@+X-D0`/"<2,@Q`C``(4HH!B`H*``$D__^(8`
MX`$#``@8@A!@*`+`0`\!````0`02#0$````1``050`02"I`2(B!____0`0``
M`)`0`!&2$``20``)5)00`!!`!!-"D3H@`$`$$X`!````0`02-@$````0;__R
M$0`$%0$````!````G>._0",`"#'"#&.@@*!@`!)```\A``@:PEPC,,180``B
MP(`*@A`@`8(`8`B?P(``PG0C,,)<(S#$6$``"OB__((`8`B"$"`!PBQCH('/
MX`@!````,&@``P$````!````G>._0('/X`@!````,&@`!0$````!`````0``
M``$```"=X[]``P`(&,188"`"P(`(D!!@(`,```""$&```L!`!`$```"?P$``
M`0```('/X`@!````,&@``P$````!````G>._0('/X`@!````,&@`!0$````!
M`````0````$```#$"@``ARB@&("@X``"0``.B!``"`,`!!:0`B`!Q%ABF,I(
M@`#$"@``@SC@&("@0`6'**`8B61`"("@X``23__ZD`(@`8'#X`B0$``$,&@`
M!0$````!`````0````$```"=X[L`N`>E;X(0/__P=ZA_A@8@.(@0`!R+,'`@
MN@>E[\)8P`"%,'`@@@A`!<)Q(`B$"(`%Q'$``(@!(!"`H0`=$F__^(8`X`B"
M$#__N@<B:*\P<""*!Z77Q%E``,)9?]C(67^H@AA``L99?YB"&$`$@AA``X4P
M<!^"`$`!A!"``80(@!?$<6`8B@%@"("A0!TR;__SQ%E``,)?J'\?%J">)QNV
M>L1?J'^>$^&9IA3CH<)80`#P7Z6GPG>CMXDP<!OV6*`(L`8`#\98H""%*'`%
MPE^H?X@1``+$7ZA_B`D`%_A88!#"7Z5OREB@&+H/`!N&`,`!PE^E=X8`P`^$
M*4`;V%^EOX8`P`3(7Z.WB@%``<)?I7^$$(`=B@%`#[0O``2&`,`"^E^EAXDN
M\!ZX!P`!PE^CM[<V\`*&",`7U%^EU[86P`2Z!T`/T%^E[[8.P!>X!P`/Y%^F
M!X0.P`&R+L`#Z%^F%X00@!JZ!T`;]E^ECX,H\`6*`4`"Q%^CMXDP\!NV!L`/
MZE^F'X@1``&8`P`/B`D`%Y0"@`^#,+`"B@%`!(4HL!Z*"4`7@A!``I`"``^"
M"$`7I`2`#[0(P`&:*$`%B2EP!;(60!KT7Z6?A3%P&[@'`!F$$(`$M@;``<A?
MI9>#*/`>A`B`%X<P\`*X!P`"AA#``;@/`!>&",`7B`$`#[()0`.6*,`<A2\P
M!9H30!GR7Z6O@S<P&[H'0`W:7Z6W@A!``H@!``.%*7`>@@A`%XLQ<`*Z!T`!
MBA%``KH/0!>*"4`7M`:`#X8/``62*4`=A2]P!982P`.#-W`;M@;`"]9?I<^"
M$$`"M`:`!<I?I<>%+S`>@@A`%[DW,`*V!L`!N!<``K8.P!>X#P`7L@9`#X8/
M0!R@+P`;A2[P!9(20`.#-O`;B`$`"=)?I>>"$$`"L`8`'/A?I=^%+W`>@@A`
M%[LW<`*(`0`!NA=``H@)`!>Z#T`7F@-`#X8.P!VB+T`$A2DP!:`4``.#,3`;
MM`:`$.!?I?^"$$`"L@9`'?I?I?>%+O`>@@A`%[<V\`*T!H`!MA;``K0.@!>V
M#L`7B@%`#X8)`!N6`L`/A2ZP!:(40`.#-K`;L`8`$>)?I@^"$$`"N`<`#X4I
M,!Z""$`7B3$P`K`&``&($0`"L`X`%X@)`!>2`D`/A@Z`!+H'0`^%+C`%H`0`
M#X,V,!N>+L`:GA/``X(00`+&7Z8OL@9`#X((0!?>7Z8GA2ZP'H8`P!/&=Z5/
ML@9``<)?IC>:`T`;M3:P`K(.0!>T%H`"@@!`$\)WI3^T#H`7MBD`&(8.`!J8
M`P`$A2YP!;86P`.#-G`;F@-`&X(00`*(+H`9@@A`%XH!0!KT7Z8_F@-``<)?
MID>B!$`3A2XP'IH+0!>"`$`3PG>E'Z@%`!/"7Z9/L38P`JH%0!.P%@`"G@/`
M$[`.`!>"`$`3PG>E#X8.0!BV+@`-A2MP!8@1``.#,W`;F`,`!((00`*6`L`8
M\%^F5X((0!>T!H`3F`,``<)?IE^P!@`3A2YP'I@+`!>S-G`"@@!`$\)WI._"
M7Z9GLA9``H4K,`6R#D`7@@!`$X8+0!G"=Z3?@S,P&[86P`."$$`"B@%`&X((
M0!>(+D`,B@%``<)?IG>4`H`9A2MP'HH)0!?R7Z9OFS-P`H(`0!/"=Z3/PE^F
M?YH30`*R!D`3A2EP!9H+0!>"`$`3A@L`#<)WI+^#,7`;B!$``X(00`*6`L`$
M@@A`%[8K0`66`L`!PE^FC[@'``V%*S`>E@K`%]I?IH>9,S`"@@!`$\)WI*_"
M7Z:7F!,``IH#0!.%*O`%F`L`%X(`0!.&"4`,PG>DIX,R\!NV%L`#@A!``I0"
M@!N""$`7B"L`"Y0"@`'"7Z:GD@)`#-A?II^%*7`>E`J`%XLQ<`*"`$`3PG>D
MGY@#`!.*$4`"YE^FKP,CQN^*"4`7@A!@W(8*P`6%*K`%I@3``8,RL!N($0`#
M@A!``K@'``3$7Z:W@@A`%P<CQN^&$.#<N`<``<)?IK^$`(`#Q'>DE[@/`!>%
M*O`>@@!``\)WI(^7,O`"PE^FQ[8I0`J6$L`"D`(`!98*P!>"`$`#PG>DAX8*
M@`N(*L`<MA;``P<CQN^%+S`%D@)`&_9?IL^#-S`;AA#@W((00`(%(\;O@@A`
M%X00H-RV!L`"D@)``<)?IM^%*K`>N@=`"]9?IM>5,K`"D@I`%Y02@`*"`$`#
MPG>D?Y0*@!>6`L`#A2IP!88/``J#,G`;B!$``X(00`*0`@`$@@A`%PDCQN^0
M`@`!PE^F[X@1(-R%+S`>D`H`%X(`0`3"=Z1WBBJ`"<)?IO>Y-S`"H`0`"K@7
M``+47Z;GN`\`%X(`0`3"=Z1OA@I`')0"@`2%*C`%BA%``X,R,!NZ!T`%@A!`
M`@<CQN^""$`7B"\`"+H'0`'"7Z<'AA#@W*0$@!P%(\;O^%^F_X(`0`.$$*#<
MPG>D9[@'``+"7Z</N@]`%X4J<!Z3,G`"@@!``\)WI%^#-W`;DA)``H4O<`62
M"D`7A@H`"8(00`*($0`#@@A`%Z`$``0)(\;OH`0``<)?IQ^($2#<A2HP'J`,
M`!>"`$`$PG>D5XHJ0!W"7Z<GD3(P`J($0`F0$@`"TE^G%Y`*`!>"`$`$PG>D
M3X8/0`BH!0`(A2PP!8H10`.#-#`;I`2`!<I?IR^"$$`"Q%^G-P<RF+"""$`7
MAA#AUJ0$@`'"7Z<_A`"`!,1WI$>%+W`>I`R`%X(`0`3"=Z0_D@)`!,)?IT>[
M-W`"B@%`!+H70`*Z#T`7@@!`!,)WI#>%++`%D!]`"(,TL!N0&@`0@A!``J($
M0`C07Z=/@@A`%ZH%0!V%+#`>H@1``<)?IU>A-#`"H@Q`%Z`4``*"`$`#PG>D
M+Z`,`!>0`@`#A2QP!;H<`!V#-'`;NA]`$H(00`*H!0`=Q%^G9X((0!>>`\`0
M^E^G7Z@%``'"7Z=OA`"``\1WI">%++`>J`T`%X(`0`/"=Z0?N@=``\)?IW>E
M-+`"I!2``H(`0`/"=Z07I`R`%\)?I4^%+3`%H!R`$*`<`!&(`$`2J@5`$.!?
MIW^#-3`;@A!``L1?IX>@!``#@@A`%X0`@`.J!4`!Q'>D#\)?IX^%+'`>J@U`
M%Z,T<`*"`$`#HA1``L)WI`?$7Z4_H@Q`%\)?IY>D'$`2A`"`$<1WI3>D'(`4
M@@!``\)WH_^>`\`2A2UP!>1?IY^#-7`;@A!``L1?IZ>D!(`#@@A`%YX#P`'"
M7Z>OA`"``\1WH_>%+3`>G@O`%ZDU,`*"`$`#PG>C[\)?I[>H%0`"A2OP!:@-
M`!>"`$`#HAT`$<)WH^>#,_`;HAQ`%8(00`*(`0`1Q%^GQX((0!>T!H`4XE^G
MOX@!``'"7Z?/A`"``\1WH]^%+7`>B`D`%X(`0`/"=Z/7H@1``\)?I]>K-7`"
MJA5``LAWI6>"`$`#PG>CSZH-0!?"7Z4?A2DP!:@=0!2H'0`/@@!`%<)WI1>#
M,3`;R%^E-X(00`+$7Z?GJ`$`%.AWI2^""$`7Z%^GWXDK\!Z$`(`#Q'>CQY\S
M\`+$7Z4OJ`4``YX3P`2>"\`7R%^E9X(`@`&J&\`5@@A`%\)WI5>J'4`$QE^E
M5X,P<!NT!H`5A2CP!8<I,!Z"$$`"Q%^E#X((0!>$`(`/Q'>E![0&@`&%,3`"
MM`Z`%X,VL!N$$(`#Q'>E)\9?I2>%+K`%@A!``L1?I5>(",`7QE^E%X((0!>>
M&0`/L`8`!)X;P`*$`,`/WE^E5X(`@`&'*_`>J@A`%X4S\`*#-7`;AA"``X4M
M<`6>",`7QE^E!X@;P`2"$$`"A!D`&H((0!?$=Z3WA`#``LA?I.^'+K`>@@"`
M`8((0!?"=Z5?B`$`#[4VL`+(=Z3G@S!P&[06@`/&7Z5?M`Z`%\A?I-^%*/`%
MAAZ`#]Y?I5^"$$`"A!C`%8((0!>P!@`"ARUP'K`&``&%-7`"L`X`%X@!`!J&
M$(`#R'>DUX4N,`6(",`7@S8P&[09`!J"$$`"Q%^DY[0>@`^'*_`>@@A`%[0`
M@!JR!D`$A3/P`H(&@`&&$(`#J@A`%X4M<`6>",`7@S5P&X8;P`3(7Z3/@A!`
M`H08P!C&7Z37@@A`%X@!``_(=Z3'A`#``H<N,!Z"`(`!L38P`K0(0!>%+K`%
ML!8``X,VL!NP#@`7AAX`#X(00`+>7Z2_A!C`%8((0!>R!D`"G@/`&-YWI+>%
M-7`"L@9``8<M<!ZR#D`7@S9P&X80@`.%+G`%B`C`%[`9`!B"$$`"Q%^DQ[`>
M`!J""$`7L`"`&)H#0`2%-K`"@@8``8<NL!Z>"$`7@S/P&X80@`.%*_`%M`C`
M%X8>@`2"$$`"R%^DKX08P!G&7Z2W@@A`%ZH!`!J$`,`"ARYP'H(`@`&S-G`"
ML`A`%X4N,`6R%D`#@S8P&[(.0!>&'D`:@A!``H08P`^""$`7AROP'IH#0`+$
M7Z2GF@-``;0`@!F:"T`7A3/P`H,S<!N&$(`#A2MP!8@(P!>R&0`9@A!``K(>
M0!B""$`7A`5`&9@#``2'+C`>@@"``84V,`*>"$`7@S/P&X80@`.%*_`%L`C`
M%X8>``2"$$`"A!C`#<9?I)^""$`7A`:``K0`P!B"`(`!ARMP'H@(0!>;,W`"
MA2DP!9H30`.#,3`;F@M`%X8;0!B"$$`"A!C`#X((0!>8`P`"I@3`#84S\`*8
M`P`!AROP'I@+`!?>7Z2/@S,P&X80@`.%*S`%A@C`%YH8P`V"$$`"FAM`!(((
M0!>%*3`>L@:`#8DQ,`*"!D`!A!$``LA?I)>T"$`7L@B`%X(60`.P`0`#@@L`
M`88.0`."$$`#F@/`&8<NL`6F!,`!B2LP'H4VL!N9,S`"A!"``Y@3``2$"(`7
MF`L`%Z8$P`+$7Z2'@A,`&:8,P!>&"P`9@@Z``:H`@`R"$$`#A33P&[(&``&'
M+/`%B2ZP'H00@`.#-K`"A`B`%X800`2"!D`"L@C`%YX(0!>"%D`,F`Y`#(<K
M\`6"#,`!A3/P&X(00`R)+/`>A!"``Z<T\`*"`T`!A`B`%Z84P`2F#,`7@@!`
M`IH(0!>"%,`9A@S`&8(+P`&"$$`#M@;`&8<K<`68!4`!A3-P&Y8"P!.)*_`>
MA!"``X,S\`*$"(`7WE^D;X800`2"`P`"F`C`%[((0!?&7Z1_B2MP'H(3`!."
M"T`!I@L`$X(00!.T`,`,A39P&[8&P`&#,W`"ARYP!8(00`2:"$`7A!"``X(3
M0`R$"(`7A@M`#+8&P`*"#D`!M@[`%X(00`.4`H`-AR[P!98"P`&)+G`>A3;P
M&X,V<`*$$(`#@A!`!(0(@!?(7Z1WF`A`%Y8"P`*"$P`-E@K`%X8+``V"#L`!
MA3+P&X(00`.'*O`%L@$`#(00@`."!H`!B2[P'H0(@!>W-O`"@@!``K86P`2:
M"$`7B2KP'K8.P!>"%L`,A@[`#((*P`&T`\`;WE^D5X4S<!N"$$`#ES+P`I0"
M@`&'*W`%EA+`!(00@`.6"L`7A`B`%X(2P!N4`H`"M@K`&Y0*@!>""T`!@A!`
M&[@'``N'*K`%L`9``84RL!N)*W`>A!"``X,S<`*$"(`7AA!`!((&``+$7Z1G
MF@C`%[`(0!>"$T`+M@"`#98+0`N""H`!ARXP!8(00`N%-C`;@@:``8DJL!Z$
M$(`#E3*P`H0(@!>4$H`$@@!``LA?I%^4"H`7F`A`%X(2@`V&"H`-@@X``;0!
M``J%,S`;@A!``XDN,!ZX!P`!ARLP!8,V,`*$$(`#@A!`!(0(@!>:"$`7N`<`
M`H(30`JX#P`7E`M`"H(+``&"$$`*D@)`#8<O,`6F!L`!A3<P&XDK,!Z$$(`#
M@S,P`H0(@!>&$$`$@@3``I@(P!>F"$`7@A,`#88+``V"#P`!M@/`#-Y?I#^%
M-/`;@A!``X<L\`6"!H`!B2\P'H00@`.Y-S`"A`B`%[@7``2"`$`"Q%^D3[@/
M`!>4"$`7@A<`#(8/``R"#,`!M`"`'(DL\!Z"$$`#A3*P&Y("0`&'*K`%@S3P
M`H00@`."$$`$A`B`%Y@(0!>2`D`"@A,`')(*0!>X"P`<@@J``8(00!R*`4`,
MARIP!98&P`&%,G`;B2JP'H00@`.#,K`"A`B`%X800`2"`L`"R%^D1Y0(P!>6
M"$`7@A*`#(8*@`R""D`!N`$`"H4R\!N"$$`#ARKP!8(&@`&)*G`>A!"``Y,R
M<`*$"(`7DA)`!((`0`*2"D`7F`A`%X(20`J&"D`*@@K``;8#P`G>7Z0GA3,P
M&X(00`.)*O`>B@%``8<K,`6#,O`"A!"``X(00`2$"(`7E`A`%XH!0`+$7Z0W
M@A*`"8H)0!>2"H`)@@L``;0`@`J"$$`)AREP!:8'``&%,7`;B2LP'H00@`.#
M,S`"A`B`%X800`2"!,`"F`C`%Z8(0!>"$P`*A@L`"H()0`&0`@`,A33P&X(0
M0`.'+/`%@@;``8DI<!Z$$(`#BS%P`H0(@!>*$4`$@@!``LA?I"^*"4`7D@A`
M%X(10`R&"4`,@@S``;@!``6%,G`;@A!``X<J<`6"!H`!B2SP'H00@`.'-/`"
MA`B`%X(`0`*$$,`$F`A`%X@(@!>*&0`%N@=`!(4K,`6*&4`)@S,P&Y`"``6'
M*G`>@A!``H4R<`*""$`7D`(``8(0@`.2"$`7D`H`%X0:0`2V`\`)WE^D!X,R
M,!N&&(`,A2HP!8@'``.'*S`>@A!``H4S,`*""$`7@@$``800@`.*"$`7B`B`
M%\)?I!^$&0`)N`!`!(88@`B#,7`;N@=``X4I<`6'*C`>@A!``I$R,`*""$`7
MD!(``[H'0`'&7Z07D`H`%[H/0!>$&@`$M`#`"(,W<!N&&(`%A2]P!8@&P`.'
M*7`>@A!``H4Q<`*""$`7@@$``800@`.*"$`7B`B`%Y`9``B@!``$A2EP!9`:
M`!V#,7`;D@<`"(<O<!Z"$$`"NS=P`H((0!>Z%T`#@@)``;H/0!>2"$`7@S)P
M&X0?0`3(7Z0/AAB`!84J<`6X`0`=@A!``H@&@`.%,7`"@@A`%X<I<!Z"`0`!
MA!"``XH(0!>#,7`;B`B`%[H9`!VV`\`$WE^CYX4I<`6Z'T`)@A!``J`$`!V'
M*G`>@@A`%X4R<`*@!``!@A"``Z`,`!>2"$`7PE^C_X0:0`2Z`$`)AAB`!8,T
M,!N(!P`#A2PP!8<I<!Z"$$`"A3%P`H((0!>$$(`#@@$``8@(@!>*"$`7A!D`
M":0$@`2#,7`;AAB`$(4I<`62!L`#ARPP'H(00`*A-#`"@@A`%Z`4``."`D`!
MQE^C]Z`,`!>2"$`7A!P`!+@`P!"#,G`;AAB`!84J<`6(!T`#AREP'H(00`*%
M,7`"@@A`%X(!``&$$(`#R%^C[Y`(0!>*"(`7H!E`$+H!``6%*C`%H!P`"8,R
M,!ND!(`0ARIP'H(00`*%,G`"@@A`%Z0$@`&"$(`#B`A`%Z0,@!>$&0`%M@/`
M!-Y?H\>#-+`;AAB`"(4LL`6*!P`#ARHP'H(00`*%,C`"@@A`%X00@`."`4`!
MB@B`%Y`(0!>$&4`$H@1`!8,R,!N&&(`2A2HP!8@'0`.'++`>@A!``J4TL`*"
M"$`7@@$``:04@`.("$`7I`R`%\)?H]^$'(`%N@!`$H88@`B#,3`;B@;``X4I
M,`6'*C`>@A!``H4R,`*""$`7A!"``X(!0`&*"(`7Q%^CUY`(0!>#,C`;I!E`
M$K@`@`6D'(`$A2HP!:($0!*'*3`>@A!``H4Q,`*""$`7H@1``8(0@`/&7Z//
MB`A`%Z(,0!>$&0`%M@#`!(,T<!N&&(`(A2QP!8H'0`.'*C`>@A!``H4R,`*"
M"$`7A!"``X(!0`&*"(`7D`A`%X090`2H!0`%@S(P&X88@!&%*C`%B`<``X<L
M<!Z"$$`"HS1P`H((0!>B%$`#@@$``:(,0!>("$`7A!Q`!;H#P!&#,3`;AAB`
M"(4I,`6*!L`#ARHP'H(00`*%,C`"@@A`%X00@`."`4`!B@A`%Y`(@!>#,7`;
MHAH`$84I<`6B'$`$@A!``J@%`!&%*3`>@@A`%X<Q,`*H!0`!R%^CMX(0P`*H
M#0`7ARTP!9((0!>%-3`;@AI`"((80`6$$(`#G@=``80(@!>#*7`>G@/``H<Q
M<`*>"\`7A`/`!-Y?J'^&$,`!@@B`%XH(P!?"<\``PEO@",1;X!#&6^`8J`4`
M`<A;X"""`4`"J`T`%X0"0`.""$`7Z'/@"(8"``3"<^`0A`B`%X((P!?$<^`8
MPG/@(('/X`@!````,&@`!`$````!`````0```)WCOT`*Q@`$`P`(,H'/X`B0
M$"``YEACT`+\__T!````PDX``(088#V`H``!AD`@`("@``*"0"``@(C``0)`
M``Z4$"``B!``&(@!(`'"20``A!A@/8"@``&&0"``@*```H)`(`"`B,`!,D__
M^8@!(`&4(0`8X%S```+T/^6E.J``$&@`!J(0`!.B!&`(X%Q```+T/]\!````
MD!``$)(0`!A`!`PXE!``$BKZ/_FB!&`(PDR`$("@8#T23__TD`2`$((D0!.#
M.'`#PB9``(''X`B1ZB`!,&@``P$````!````G>._,*`'I^N0$``8DA``$'__
M_\0C``@R`L(`#L)'I^O$7&/0@RAP`X0`0`*$`*`(PEB```KX?_["<+_XD!``
M&'___[B2$``0"OH_]L)'I^N!S^`(`0````$````!````G>._,)`0`!A___^N
MD@>GZX''X`B1Z``(`0````$```"=X[]`,0`(,<(&(MR`H'__`D``!!$`!!6!
MS^`(T$(BW'____"0$B(X`L(`!X(0(`#"2@``@*!@`!)(``:"&&`P@A`@`,(F
M(MR!S^`(T$(BW("@``&"0"``$&___,(F(MR=X[]`,0`$#I`0/_^R$"``0`0+
M;+`6($`0A`RR@>@```$````P:``'`0````$````!`````0````$````!````
MG>._0`,`"#$C``@QQEAC``4`"#$1``06REQC&)`2(AB2$"``PEC@(,8(HNC(
M66`(@S!P-X,H8`>&".!_@A!``\(Q(`+$7&,80`0,1N!8H`C0="`H`P`(,8H0
M(`#(7&,8QEAC"`,`"#'$62`(QG"@,,1<8QC"6&.8`L!``\18H`C*6&"HRG"@
M.,)<8QC$6&`(P'"@0,)<8QC$6&`(`P`(,<!PH"#(7&,8QEAC(,19(`C&<*!(
M@<_@"`$````!````G>.^P`+&`$D!````PDX``("@8``20``$`0```('/X`@!
M````0`0+[Y`0`!@"\C_\I!``"`,`!!4%``05IA!B2`,`!!6H$*)0K!!B6*H'
MIW<O```\.P``$$`$"OJ0$``2DA``$P+"`"NB`B`(0`0,39`0`!$"^C_YDA``
M%$`$#$F0$``1`OH_]0$```!`!`M%D!``&*`0``A`!`M"D!``$9`"`!"0`B`"
M0`0*=I$Z(`"2$``6E!``&)80`!%`!`L9H!``")`0`!!`!`KFDA``%8"B/_\"
M0``&PA>G?X((0!>`H$`=`D``$P$```!`!`K-D!``$$`$#`.0$``00`0*T9`0
M`!*2$``3"OH_V:("(`A`!`P<D!``$D`$"V*0$``8@<_@"`$```"!S^`(`0``
M`'___[20$``0$&__[P$```"=X[[`D@>G=T`$"SZ0$``8@*(@`!)```_&%Z=_
M`P``/`4``!"&",`!`P``*(08P`*&&,`!@*```HA@/_^`H``#@F`__X"1``$2
M0``%D!``&+`0(`"!S^`(D3H@`$`$"V&2$"`"@*``"+!@/_^!S^`(D3H@`#!H
M``,!`````0```)WCOS#"3D``@AA@/8"@``&$8#__L@9``D`$"O*0$``9IA``
M")('I^M___[6D!``&`+"`%:@$``(0`0*ZBD`"#*#-.``@*(``3IH`$'"#D``
MPDX``!!H``.($``8PDD``(088#V`H``!AD`@`("@``*"0"``@(C``3)/__F(
M`2`!D`3@`N`'I^N0(@`8XETCT*$L,`.0`@`$0`0*"I$R(``"P@!CT'0`$<0'
MI^L#``@RR%ACT,8.``"%*+`#R%D``H,HX!B#.&`8@*!@``)``!+&*0``@*!@
M/0)``!""$"`]$&@`!88&(`&`H&`]`D``"X(0(#W$",``B`$@`88`X`&#**`8
M@SA@&("@8``23__WQ"D``((0(#V$`2`!PBD``,(.0`"R!F`!PBB``(,H8!B`
MH&``$D__^X0`H`&P$"``@<_@")$Z(`#"#D``L@9@`<(L``"#*&`8@*!@``)'
M__B@!"`!P@Y``+(&8`'"+```@RA@&("@8``23__TH`0@`1!O__"P$"``*0`(
M,J(0(`#072/0PEH```+`0`J2$"`0A!``"(0`H`C"6(``"OA__J($8`&"!&`"
M@SA@`),H<`,%``@QP@"CJ("@8``22``2@A`@`9`0``E`!`FZPB"CJ`+"`!.D
M$``(@SQ@`-)=(]"A*'`#0`0+:Y00`!#D=2/0PETCT(($``'`<&`($&__D>(G
MI^M`!`KS`0```(,\8`#0=2/0"OH_]Z$H<`.P$#__@<_@")$Z(``!`````0``
M`)WCOP`#``06!0`$%<!WI^?J6&*@`P`$%800HGB"$&)PQ'>GQP4`!!7"=Z>_
M`P`$%800HHB"$&*`!P`$%<)WI\^&$.)@Q'>GUP,`!!4%``05@A!BH,9WI[>D
M$``#J!"BL,)WI]\0:``'I@>GOW___U60$``2Y%S```+$@":F!.`(?__^@)`0
M`!*B$``(`O(_^)(0`!C"2@``@*!@``)/__0!````0`0*WY(0`!@J^C_SY%S`
M`$`$"CN0$``8H!``"$`$"CB0$``5H`0`"$`$"C60$``1H`0@`4`$"6J0!``(
MDA``%)00`!B6$``5F!``$4`$"@R@$``(D!``$G___S&2$``0Y%S```K\O]ZF
M!.`(@<_@"`$````!`````0```)WCOQ`#``@Q$P`$%J@08RB2$F)PE!`@(I`'
MI\7"70``PG>GYX(0(`!`!`JN)P`$%1$`!!60$B*X?__^,B4`!!41``05(P`$
M%9`2(LA___XM(0`$%1$`!!5___XJD!(BT!$`!!5___XGD!(BX'___B60%.+H
M$0`$%7___B*0$B+X?__^()`4HPA___X>D!1B.'___AR0%",8$0`$%7___AF0
M$B,H$0`$%7___A:0$B,X$0`$%7___A.0$B-($0`$%7___A"0$B-8$0`$%7__
M_B60$B-H`L(`!)(0``A___[QD!0C&!$`!!5___X>D!(C@"+"``<1``05DA``
M"!$`!!5___[HD!(CF!$`!!5___X5D!(CJ`+"`!"2$``(?__^X9`4HP@3``05
MD!3BZ'___MV2$F/@PE^GY\1=``""&$`"A!`@``K`0!D!````@<_@"`$````1
M``05?__^`I`2([@"P@`&DA``"'___LZ0%&(X$&__[A,`!!43``05D`>GUI(2
M8]!`!`H'E!`@"BKZ/^<3``05D!1B.'___L*2!Z?@$&__XA,`!!5`!`HF`0``
M``$````P:``#`0````$```"=X[]`0`0)W[`0(`!`!`CUD3(@`"K*``+P6@``
M@<_@"`$````P:``'`0````$````!`````0````$````!````G>._0"+&``@Q
M``05P@X``*$H8!B`I"``$D``!0$````Q``05$(0)9Y'N(DA`!`F5D!``&)`"
M`!B4`C__@*8`"AI@`!4+``06PEEBF-`*/__$"$``D2H@&(DHH!B`H0`($D``
M*(,Z(!@0:``'AA```8,H8!B%.&`8@*"``Q)``"&0$``!E`*__X"F``HJ;__Y
MP@J``("B@!@28``*QEEBF/!98IB%/"`8PDX``("@@`$B1__=,0`$%1"$"4*!
MZ```E`*__X"F``HZ8``(E"*`&,1*@`#"2,``@*"``2)/__J4`K__E"*`&(("
MH`*`H&0`"&``%*`0(`"!Q^`(D>@`$!!H``.%.2`8D2H@&(,Z(!B`H(`!`D?_
MX8"B@!B4`K__@*8`"BIO__G0"H``@**`&")O_]WP66*8$&__XL998I@A``@Q
MDA``&)`4([!`!`FUE`*@`1!O_^F@%".P`0```)WCOT!___^GD!``&'__]PT!
M````?__]@Z(0``B`HB```D``"`$````"Q@`&`0```,).``"`H&``$D``!!,`
M!!6!S^`(`0```)`0`!%`!`G5DA)CZ("D0`@2;__Z`0```'___<B!Z````0``
M`#!H``4!`````0````$````!````G>._,)`'J'^2!ZB'\G>HAY0'J(_T=ZB/
M0`0*"O`GJ'\#``@QQ$AC<("@H``"0`!A!P`(,<('J'_$".+P@@!@!9$X8`"$
M$*`#!L(`:\0HXO#0=Z?G@A```-$?I^?"=Z?O@A`A#Y6@$0C1'Z?O@RAP-L)W
MI^^1HHA(U1^G[X&J"LHM2`!P$0`$%4`$";Z1*C`#RE^HAP,`"#*&$"`$T'!C
MR`,`"#*6$``(Q%E``)H"/_C4!ZA_Q'(```4`"!K&(&/``P`$%800HSB"$&/X
MPG(@"("BH`$#``06Q'(@$((08``$0``+PG(@&(@0(`&&$"`(Q%E``X("P`.(
M`2`!A@#@"("B@`043__[Q'!@&(("H`0U``@R@SA@`-!>H["4`J`#@RAP`Q,`
M!!62$F&`F!`@`,!S0`%`!`@KE3J@`+"2(``"0`!$`0```$`$"2[07J.P$0`$
M%7___0N0$B+X`L(`"3,`"#+07J.P0`0(#K$^(`!`!`B\`0```('/X`@!````
MT%YCN"+"`#<1``05?___?0$```#07J.P0`0(`K$^(`!`!`BP`0```('/X`@!
M````0`0(=`$````#``@R`L(`,=!P8[!`!`C7`0````,`"#$'``@QP"ABX,('
MJ'_$".+P@@!@!9$X8`"$$*`##OH_F<0HXO"#,C`!A`H@`8(00`+"=Z?GU1^G
MYX(0``#"=Z?O@A`A#Y&@$0J#*'`VE:((2-$?I^_"=Z?OD:*(2-4?I^^!J@K*
M'4__E0$````1``05$P`(,9`2(_!`!`EFDA)C>$`$!_S07J.P$&__O+`0``A_
M__S(D!(C"`+R/[_0=F.X?___1`$````0;__(T%ZCL$`$"5"0$"`!`0```#!H
M``4!`````0````$````!````G>.ZP`,`"#$1``05NA!C*)`2(PC"7T``PG>G
MYX(0(`!___RP`0````,`!!:B$``(X%ABF)`0`!A`!`D2DA``$`+"``X!````
M$0`$%9(0`!A___UTD!(C.,)?I^?$7T``@AA``H00(``*P$!>`0```('/X`@!
M````0`0(8I`0`!@#``06I!``".988J"0$``90`0'[)(0`!,"\C_LLA``"`,`
M!!6H!*`!JA!B2`,`!!6L$&*PI`>CYZX'HV\Y```\-P``(,).0`"`H&```L1`
M![-D0!60$``10`0)2I(0`!D"P@`M`0```$`$"$:0$``9@SH@`,A,``"*`C__
MASE@`((&0`'$2'__@*"`!`)(``6&`,`9$&@`#8(%``B*`C__P"C``)`0``7"
M"/__Q$P``(,H8!B#.&`8@*!``@)/__B&`/__@@4`"("@8_\41_^_E!``&980
M`!"8$``8DA``%D`$"`B0$``2D!``$D`$!]62$``7@*(@`!)```;"%Z-W@@A`
M'("@0!L"0``)D!``$I`0(`!`!`>KDA``$PKZ/\JR$``($&__JA$`!!5`!`AU
MDA`@`8"B(``R3__WD!`@`!$`!!62$``2?__]%I`2(SA`!`?<D!``$A!O_Z"P
M$``(0`0(>`$````!````,&@`!0$````!`````0````$````#```@@AA]D)WC
M@`$#``@Q!0``(+H08RB$&+\(PE]``,)WI^>"$"``B@>G_Z@'I^^(!0`"A@%`
M`CD`!!4#``06P'$@$`4`!!:"$&`(PG#_\(00H!"0%R,(?__\(L1Q(`BL$``8
M`L(`!J`0``C"2@``@*!@`!)``,@!````?__^,:`0(``#```@IA``"((8?P@"
MP@")I`4``<(,P`"#*&`8@*!@``)``!L+``@QB!``$QL`"#&%.&`8@*"@``9`
M``W"`6+T@*"``19(``N"$"!?@SB@`,9;8VB#*'`#@@!``\188$"`B*4`,F@`
M!8@!(`&"$"!?PBD``(@!(`'""0``@RA@&("@8``23__LA3A@&`,``""*!Z?_
M@AA^V`D`!!6&!0`!A`%``0,`!!:($2.8R'"_\((08"C"<.`(!0`$%@,`!!:$
M$*`PP'#@*((08#C"<.`8H@#@"`,`!!;$<.`0@A!@0!!H``7"<.`@R%Q```+!
M`&"B!&`(?__[VI`0``0"\C_[H!``",)*``"`H&``(D__^,A<0`!___R"`0``
M`("B(``B3__SR%Q``$`$!V60$``0`LH`4*00``A`!`>1D!``$J`0``A`!`>.
MD!``$Y`"`!"0`B0$HSH@`$`$!L&0$``1`P`$%A,`!!;N6&*8&0`$%9(28%B4
M$``2F!,CZ)H0`!.6$``70`0'7JH0``B0$``50`0'LY(0(<"`HC__`D``8P,`
M`""0$``5@AA^8*0%``%`!`>;DA``$H"B(``20``(!0``/,(4H`@'```0@@A`
M`H"@0`,"0`!I`0````,`"#$3``06U%V``-!88Y"2$F#XEA``%4`$!SJP$"``
MPE^GY\I?0`""&$`%BA`@``K`0+D!````@<_@"`$```!`!`<H`0```*80``@*
M]/][H`0@"-!<`!("P@"M`P`$%G__^X@!`````O(_^0$```#"2@``@*!@`!)'
M__(!`````OS_]:`$(`@0;_]MP@S``*00(``'``06!0``(-I(X$B$&+\@@@>G
M_X@%``**`$`"`P`$%880X$C`<2`0@A!B2,9Q?_"B$``#PG$@"("C8``"1_^C
MH`$@"'___!J0$``1@*(@`!)``!`!````"O2_G`$```#B7````O1_F0$```#"
M3$``@*!@``)'_Y6@!"`(?__\#)`0`!&`HB```D__]`$```!`!`;OD!``$1!O
M__"D$``(?__\LP$```!`!`;ID!``$!!O_[>P$``(0`0'G0$```#"`@``@*!@
M$0)/_YL#```@`P`(,>)=@`"P$"``0`0'E.!88Y#80@``$P`$%I`0`!"2$F!H
ME!``$4`$!MV6$``5$&__HP$```!`!`<QX`2@#("D``@23_^7`P`(,<(4H`B"
M"&'_@*!AP!)/_Y(#``@Q0`0&+Y`0`!&P$``($0`$%7__^RN0$B*`(L(`">)=
M@`!`!`:_X%V``)(0``A___YLD!``$`+"`$FB$``(0`0&Z)`0`!&`HB`#%$`!
M)Z`0``A___LC`0```("B(``22``)$P`$%9`0`!%`!`8]DA`@`("B(``R0``[
MK3H@`!,`!!41``05DA)CX'__^]V0$B(X0`0'>Z`0(``#``06$P`$%IH08AB2
M$F#0F3H@`)00`!60$``8EA``%T`$!JFB$``-`P`$%A!H`!*D$&#@0`0'3`$`
M``#"`@``@*!@$1)``!(!````0`0'9J`$(`'B<ZBODA``$IDZ(`"4$``5D!``
M&)80`!=`!`:6FSP@`)`0`!A`!`;KDA`AP("B/_\"3__L`0```$`$!X:0$``5
MD!<C"'__^[.2$``8?__\09`0`!@0;_]'`0```!!O_NFF$&`@0`0'$P$````0
M;_^YXEV``"$``""2$#_NE!`@`J`</SA`!`:3D!``%J(%`!"0$``6E!`@!D`$
M!J:2$``1A`>G_X(`@!#$"'_P@*"@`!)```>0$``6P@Q@`8"@8$,B0`#WP@Q@
M`I`0`!:2$"``E!`@`$`$!G\U```@P'>G3X0>OS@#&=%(P'>G5[8%``*"$&,!
MPG>G)P4[\VH#)BZWP">GGX00HXF"$&#^Q'>G+X00/__"=Z<W`P0,E;,PL"`%
M,/2X@A!@=H00H?#"=Z<_J`>G)\1WIT>0$``6DA``&T`$!GR4$``:HI(@``1`
M`#K$7Z=/ASQ@`(,H\`."`$`"B`A`&8"@@`0(:``$Q%^G5X0`H`'$=Z=7@S#P
M'=`'IY^@$``;@@"``<AWIT^D!Z=?@*(@``)(``O"=Z=7$&@`$8(0($"4$"!`
MD!``$D`$!NFB!'_`D!``%'__]"Z@!"!`@*1@/Q1/__B2$``0D!``$D`$!N"5
M/&``$&__V.(GIY^2$``;@B!`"*`0``&`I$`!H62`$9$Z(`"G/"``D`2`"$`$
M!M24$``3P@>GGX($``&`H&!`$D__R<(GIY^0$``4HB1`$'__]!.@!,`;$&__
MYH"D8#]`!`87D!``%N!?IT_B7Z=7@S0P`X((8#^%.&``A@!@`80%``*"$#^`
M@*#@.`1(`(7"**`XD3C@`)00($"4(H`#D`(`%)4ZH`"2$"``0`0&S)`"(#A_
M__/ZD!``%,!WIU_`=Z=GP'>G;\!WIW?`=Z=_P'>GA\!WIX^#-'`8PB^GEY`0
M`!2%-'`0Q"^GF*@'IZJ#-#`8PB^GFZ00`!2'-'`(XB^GFJ80(`"%-#`0X"^G
MGJ('I].#-#`(QB^GF<0OIYQ___/?PB^GG<1?IR<#``06QE^G+Z`08,C*7Z<W
MFS"P&-A?IS^#,+`0UE^G1XDPL`B5,/`8VB^GT\(OI]2;,/`0@S#P",@OI]7$
M+Z?6B3%P&(4Q<!#4+Z?7VB^GV)4Q<`C"+Z?9DS,P&,8OI]J#,S`0R"^GVX<S
M,`C$+Z?<B3+P&(4R\!#4+Z?=FS+P",HOI][2+Z??PB^GX,8OI^'8+Z?BR"^G
MX\0OI^3:+Z?EUB^GYM0,P!&0$``2DA``$*8$X`%`!`6OI`2@`H"DX!0R;__Z
MU`S`$1,`!!8;``06P"^GTI(28+B6$``7F!``%)H38AB0$``80`0%HI00`!40
M;_\2`0```)$Z(``3``06D`(`$9(28*A`!`:ZD`(__`KZ/M6`I"`$`D``"8($
M/_S&3<``@SA@`(($0`'$2'__@*"``Q)/_LP!````X%V@"`+T/LD!````0`0%
MJI`0`!"`HB`#"&_^Q)`$``@3``06D`(__$`$!J.2$F"P$&_^OJ-Z!!"1..``
ME!`@.)0B@`.0`@`4DA`@`)`"(#A`!`9)E3J@`!!O_X>#-'`8@*!@01)/_PN0
M$``6P@Q@`X"@8$,23_\(DA`@`,(,8`2`H&!($D__!900(`#"#&`%@*!@11)/
M_P$!````E!`@`D`$!7V2$#_&DA``$9`0`!9`!`61E!`@*1,`!!8;``06D!``
M&)(28+B6$``7F!``$9H38AA`!`58E!``%1!O_L@!````,&@`!`$````!````
M`0```)WCMS`#``@QH`>CYJ(08RC"7$``PG>GYX(0(`!`!`81`0```!,`!!87
M``06E3H@`)(285"6$N%@0`0%0I`0`!"`HB``%D``"Z0'O^6P$"``PE^GY\1<
M0`""&$`"A!`@``K`0!8!````@<_@"`$```"0$``0DA``$D`$!*J4$"0`H)(@
M``9/__.P$"``D`0@`4`$!(21.B```O(_[;`0``BA/"``DA``$D`$!=Z4$``0
M$&__Z,`L`!A`!`6R`0````$````P:``'`0````$````!`````0````$````!
M````@A/``!!O_\<!`````0```#!H``0!`````0````$```"=X[]`$0`$%2T`
M"#&"$"`!D!(BZ'__^6/"+:,0`L(`!@$```#"2@``@*!@,2)``'#"2B`!?__[
M`P$````1``06DA`@`9`2(6A`!`26E!`@"P+"`"ZD$"``)P`(,L1:(!#"!./`
M@*!@`01``"/H6*`HHA`@"!!H``TK``@RTEH@$$`$!A"0$``0"L(`',0$X\"D
M!*`!Q`3CP(($H`&`H(`!!$``%J($8`B0$``4E!`@`$`$!523/*```L(`#\)=
M8\C06@``Q`(@#("(I``2;__LX%A`$9(0(`!`!`82E!`@`I(0``A`!`7WD!``
M$"+Z/^JD!*`!Q`3CP((`O_^`H$`2`D``0("@H`$1``06DA`@`9`2(7!`!`1C
ME!`@!`+"``Z@$``(PEH@$!,`!!:2$F%X0`0$9-!80`#"7"`0T%A```,`$`#$
M`B`,@(B``1)``#@!````$0`$%I(0(`&0$B&`0`0$4)00(`0"P@`*HA``"!$`
M!!5___D+D!(C.`+"`#B2$``(PEQ@$$`$!$[06$``$0`$%0,`"#'`+:,0D!(C
M""$`"#)___C_P'!B^`+"`"30=".X0`0$^Y(0(<""&B`1@*``"(9`(`"`H``!
MA$`@`("(P`("0``$@*(__Q)``"R7.B``@<_@"`$```"`H&```D__E!$`!!80
M;_^/`0````1'_\*@$"`!D!``%$`$!!V@!"`!P@3CP("@0!`T3__\D!``%!!O
M_[H1``060`0%'0$````0;__)$0`$%B4`"#)___R@T%RCR`K"`"#0=".X$0`$
M%D`$!6N0$B&(?___80$````"P@`1H!``",)<8!"2$``(0`0$$]!80`!`!`5I
MD!``$!!O_\01``05`P`(,M1<([C$6&/($0`$%I`2(=A`!`58TEB```4`"#+"
M7&`0QEBCR-!80`!`!`0"TEC``!!O_[41``05PEQ@$-!80`#$`B`,@(BD``)@
M`!.2$"``T%H@$$`$!`_27*/(PEQ@$*80``C$7*/(T%A``,("(`R`B&0``F``
M#.!8@`#46B`0$0`$%I(0`!"7/.``0`0%.9`2(;!`!`5_E!`@`A!O_^X!````
ME!`@`D`$!7J2$"``$&__])00``@P:``&`0````$````!`````0````$````1
M``06$P`(&14`!!:0$B(@DA)BP)02HD""$\``$(0%,0$````!````,&@`!@$`
M```!`````0````$````!````G>._0#4`!!8Q``06M!:B&#,`!!2P%B)0LA9A
MX+80`!I____HN!`@`!"$!%:!Z````0```#!H``,!`````0```)WCOT`#``@8
M@A!@",18?_B`H+__`F``"*``?_B?P(``H`0_^,1<``"`H+__$F___`$```"!
MS^`(`0````$```"=X[]`@<_@"`$````P:``%`0````$````!`````0```)WC
MOT!___&O`0```(''X`B!Z````````%!!4E]#3$5!3@`````````N````````
M`"XN````````)7,O)7,```!,1%],24)205)97U!!5$@`3$E"4$%42`!,24)2
M05)97U!!5$@`````1%E,1%],24)205)97U!!5$@`````````4TA,24)?4$%4
M2````````"5S)7,E<P``4$523#5,24(``````````%!%4DQ,24(`4$523#5/
M4%0``````````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M``````!005)?5$5-4```````````4$%27T1%0E5'`````````%!!4E]#04-(
M10````````!005)?4%)/1TY!344`````4$%27T%21T,``````````%!!4E]!
M4D=67S````````!005)?1TQ/0D%,7T1%0E5'``````````!005)?1TQ/0D%,
M7U1-4$1)4@````````!005)?5$U01$E2````````4$%27T=,3T)!3%]414U0
M`%!!4E]'3$]"04Q?0TQ%04X``````````%!!4E]#3$5!3CT````````Q````
M`````'!A<BT`````)7,````````M90```````"TM````````55-%4@````!5
M4T523D%-10``````````4UE35$5-``!435!$25(``%1%35!$25(`5$5-4```
M``!435```````"]V87(O=&UP+P`````````E<R5S)7,E<P``````````)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H
M97)R;F\])6DI"@```````'!A<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E
M<P``)3`R>``````E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P``
M````````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H
M<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``
M`````"]P<F]C+R5I+R5S``````!F:6QE`````$%21U8`````&`````````!P
M97)L`````#``````````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O
M<GD``````````"5S.B!E>&5C=71I;VX@;V8@)7,@9F%I;&5D("AE<G)N;STE
M:2D*```E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*``````````!$>6YA3&]A9&5R.CIB
M;V]T7T1Y;F%,;V%D97(``````'!E<FQX<VDN8P````````!);G1E<FYA;',Z
M.E!!4CHZ0D]/5``````Z`````````%]?14Y67U!!4E]#3$5!3E]?("`@("`@
M("`@("`@("`@`````````````````!!84```````$%IH````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````__________\``````````/__________````````````````````
M```````````!``````````$``````````0````````'^``````````$`````
M```""``````````!`````````A8``````````0````````(C``````````$`
M```````"1P`````````/`````````Z4`````````#```````$!O@````````
M``T``````!!6(``````````$```````0`<``````````!0``````$`ZP````
M``````8``````!`$\``````````*````````!-$`````````"P`````````8
M`````````!4````````````````````#```````@8P```````````@``````
M``6X`````````!0`````````!P`````````7```````0%B@`````````!P``
M````$!2H``````````@````````'.``````````)`````````!@`````<```
M`0`````````!`````'````$``````````@````!O___^```````0%%@`````
M;____P`````````"`````&____```````!`3@@``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````(&`H````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```#``"`,&__YP$````!`````0````$````!`````0````,``*`P;__?`0``
M``$````!`````0````$````!`````P``P#!O_]<!`````0````$````!````
M`0````$````#``#@,&__SP$````!`````0````$````!`````0````,``0`P
M;__'`0````$````!`````0````$````!`````P`!(#!O_[\!`````0````$`
M```!`````0````$````#``%`,&__MP$````!`````0````$````!`````0``
M``,``6`P;_^O`0````$````!`````0````$````!`````P`!@#!O_Z<!````
M`0````$````!`````0````$````#``&@,&__GP$````!`````0````$````!
M`````0````,``<`P;_^7`0````$````!`````0````$````!`````P`!X#!O
M_X\!`````0````$````!`````0````$````#``(`,&__AP$````!`````0``
M``$````!`````0````,``B`P;_]_`0````$````!`````0````$````!````
M`P`"0#!O_W<!`````0````$````!`````0````$````#``)@,&__;P$````!
M`````0````$````!`````0````,``H`P;_]G`0````$````!`````0````$`
M```!`````P`"H#!O_U\!`````0````$````!`````0````$````#``+`,&__
M5P$````!`````0````$````!`````0````,``N`P;_]/`0````$````!````
M`0````$````!`````P`#`#!O_T<!`````0````$````!`````0````$````#
M``,@,&__/P$````!`````0````$````!`````0````,``T`P;_\W`0````$`
M```!`````0````$````!`````P`#8#!O_R\!`````0````$````!`````0``
M``$````#``.`,&__)P$````!`````0````$````!`````0````,``Z`P;_\?
M`0````$````!`````0````$````!`````P`#P#!O_Q<!`````0````$````!
M`````0````$````#``/@,&__#P$````!`````0````$````!`````0````,`
M!``P;_\'`0````$````!`````0````$````!`````P`$(#!O_O\!`````0``
M``$````!`````0````$````#``1`,&_^]P$````!`````0````$````!````
M`0````,`!&`P;_[O`0````$````!`````0````$````!`````P`$@#!O_N<!
M`````0````$````!`````0````$````#``2@,&_^WP$````!`````0````$`
M```!`````0````,`!,`P;_[7`0````$````!`````0````$````!`````P`$
MX#!O_L\!`````0````$````!`````0````$````#``4`,&_^QP$````!````
M`0````$````!`````0````,`!2`P;_Z_`0````$````!`````0````$````!
M`````P`%0#!O_K<!`````0````$````!`````0````$````#``5@,&_^KP$`
M```!`````0````$````!`````0````,`!8`P;_ZG`0````$````!`````0``
M``$````!`````P`%H#!O_I\!`````0````$````!`````0````$````#``7`
M,&_^EP$````!`````0````$````!`````0````,`!>`P;_Z/`0````$````!
M`````0````$````!`````P`&`#!O_H<!`````0````$````!`````0````$`
M```#``8@,&_^?P$````!`````0````$````!`````0````,`!D`P;_YW`0``
M``$````!`````0````$````!`````P`&8#!O_F\!`````0````$````!````
M`0````$````#``:`,&_^9P$````!`````0````$````!`````0````,`!J`P
M;_Y?`0````$````!`````0````$````!`````P`&P#!O_E<!`````0````$`
M```!`````0````$````#``;@,&_^3P$````!`````0````$````!`````0``
M``,`!P`P;_Y'`0````$````!`````0````$````!`````P`'(#!O_C\!````
M`0````$````!`````0````$````#``=`,&_^-P$````!`````0````$````!
M`````0````,`!V`P;_XO`0````$````!`````0````$````!`````P`'@#!O
M_B<!`````0````$````!`````0````$````#``>@,&_^'P$````!`````0``
M``$````!`````0````,`!\`P;_X7`0````$````!`````0````$````!````
M`P`'X#!O_@\!`````0````$````!`````0````$````#``@`,&_^!P$````!
M`````0````$````!`````0``````````$%H8`````````````````"!@&",A
M+W5S<B]B:6XO<&5R;`IE=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*("`@(&EF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M
M92!S:&5L;`H*<&%C:V%G92!?7W!A<E]P;#L*"B,@+2TM(%1H:7,@<V-R:7!T
M(&UU<W0@;F]T('5S92!A;GD@;6]D=6QE<R!A="!C;VUP:6QE('1I;64@+2TM
M"B,@=7-E('-T<FEC=#L*"B-L:6YE(#$U.`H*;7D@*"1P87)?=&5M<"P@)'!R
M;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI
M('L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ
M0F%S96YA;64["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!M>2`D=&]P
M9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*("`@
M(&]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*("`@
M($9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z
M('5N;&EN:R!]+"`D<&%R7W1E;7`I.PH@("`@<FUD:7(@)'!A<E]T96UP.PH@
M("`@(R!$;VXG="!R96UO=F4@=&]P9&ER(&)E8V%U<V4@=&AI<R!C875S97,@
M82!R86-E('=I=&@@;W1H97(@87!P<PH@("`@(R!T:&%T(&%R92!T<GEI;F<@
M=&\@<W1A<G0N"@H@("`@:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU3
M5VEN,S(G*2!["B`@("`@("`@(R!3;VUE=&AI;F<@=V5N="!W<F]N9R!U;FQI
M;FMI;F<@=&AE('1E;7!O<F%R>2!D:7)E8W1O<GDN("!4:&ES"B`@("`@("`@
M(R!T>7!I8V%L;'D@:&%P<&5N<R!O;B!P;&%T9F]R;7,@=&AA="!D:7-A;&QO
M=R!U;FQI;FMI;F<@<VAA<F5D"B`@("`@("`@(R!L:6)R87)I97,@86YD(&5X
M96-U=&%B;&5S('1H870@87)E(&EN('5S92X@56YL:6YK('=I=&@@82!B86-K
M9W)O=6YD"B`@("`@("`@(R!S:&5L;"!C;VUM86YD('-O('1H92!F:6QE<R!A
M<F4@;F\@;&]N9V5R(&EN('5S92!B>2!T:&ES('!R;V-E<W,N"B`@("`@("`@
M(R!$;VXG="!D;R!A;GET:&EN9R!O;B!7:6YD;W=S(&)E8V%U<V4@;W5R('!A
M<F5N="!P<F]C97-S('=I;&P*("`@("`@("`C('1A:V4@8V%R92!O9B!C;&5A
M;FEN9R!T:&EN9W,@=7`N"@H@("`@("`@(&UY("1T;7`@/2!N97<@1FEL93HZ
M5&5M<"@*("`@("`@("`@("`@5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*("`@
M("`@("`@("`@1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D
M:7(I+`H@("`@("`@("`@("!3549&25@@/3X@)RYC;60G+`H@("`@("`@("`@
M("!53DQ)3DL@/3X@,"P*("`@("`@("`I.PH*("`@("`@("!P<FEN="`D=&UP
M("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*("`@
M<FT@+7)F("<D<&%R7W1E;7`G"B`@(&EF(%L@7"$@+60@)R1P87)?=&5M<"<@
M73L@=&AE;@H@("`@("`@8G)E86L*("`@9FD*("`@<VQE97`@,0H@("!X/6!E
M>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G
M"B(["B`@("`@("`@("`@(&-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["B`@
M("`@("`@;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL
M(#(^)C$@)B<["B`@("`@("`@8VQO<V4@)'1M<#L*("`@("`@("!S>7-T96TH
M)&-M9"D["B`@("`@("`@;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O
M8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*("`@("`@("`@("`@("X@)'1M
M<"T^9FEL96YA;64I.PH@("`@?0I]('T*"D)%1TE.('L*("`@($EN=&5R;F%L
M<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/
M3U0["@H@("`@979A;"!["@I?<&%R7VEN:71?96YV*"D["@II9B`H97AI<W1S
M("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2!["B`@
M("!`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D14Y6
M>U!!4E]!4D=#?2`M(#$I.PH@("`@)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]
M"F5L<V4@>PH@("`@9F]R("AK97ES("5%3E8I('L*("`@("`@("!D96QE=&4@
M)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PH@("`@?0I]"@IM>2`D<75I970@
M/2`A)$5.5GM005)?1$5"54=].PH*(R!F:7@@)'!R;V=N86UE(&EF(&EN=F]K
M960@9G)O;2!0051("FUY("5#;VYF:6<@/2`H"B`@("!P871H7W-E<"`@("`]
M/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*("`@(%]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"B`@("!?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\
M3U,R+R`_("=<7"<@.B`G+R<I+`HI.PH*7W-E=%]P<F]G;F%M92@I.PI?<V5T
M7W!A<E]T96UP*"D["@HC($UA9VEC('-T<FEN9R!C:&5C:VEN9R!A;F0@97AT
M<F%C=&EN9R!B=6YD;&5D(&UO9'5L97,@>WM["FUY("@D<W1A<G1?<&]S+"`D
M9&%T85]P;W,I.PI["B`@("!L;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![
M?3L*"B`@("`C($-H96-K(&9I;&4@='EP92P@9V5T('-T87)T(&]F(&1A=&$@
M<V5C=&EO;B![>WL*("`@(&]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L
M87-T.PH@("`@8FEN;6]D92A?1D@I.PH*("`@(&UY("1B=68["B`@("!S965K
M(%]&2"P@+3@L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@.#L*("`@(&QA<W0@
M=6YL97-S("1B=68@97$@(EQN4$%2+G!M7&XB.PH*("`@('-E96L@7T9(+"`M
M,3(L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('-E96L@7T9(+"`M
M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*("`@(')E860@7T9(+"`D8G5F
M+"`T.PH*("`@("1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PH@("`@(R!]
M?7T*"B`@("`C($5X=')A8W1I;F<@96%C:"!F:6QE(&EN=&\@;65M;W)Y('M[
M>PH@("`@;7D@)7)E<75I<F5?;&ES=#L*("`@('=H:6QE("@D8G5F(&5Q(")&
M24Q%(BD@>PH@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E
M860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@;7D@
M)&9U;&QN86UE(#T@)&)U9CL*("`@("`@("!O=71S*'%Q*%5N<&%C:VEN9R!F
M:6QE("(D9G5L;&YA;64B+BXN*2D["B`@("`@("`@;7D@)&-R8R`]("@@)&9U
M;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*
M("`@("`@("!M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z
M+BHO*3\H+BHI*%PN+BHI?"D["@H@("`@("`@(')E860@7T9(+"`D8G5F+"`T
M.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*
M"B`@("`@("`@:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z
M<&U\<&Q\:7A\86PI)"]I*2!["B`@("`@("`@("`@(&UY("@D;W5T+"`D9FEL
M96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PH@("`@("`@("`@("!I
M9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@
M("`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@("`@
M(&-L;W-E("1O=70["B`@("`@("`@("`@("`@("!C:&UO9"`P-S4U+"`D9FEL
M96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PH@("`@("`@("`@
M("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA
M;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@@)&9U;&QN86UE(#U^(&U\
M7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*("`@
M("`@("`@("`@(R!S:&]U;&0@8F4@;6]V960@=&\@7W1E;7!F:6QE*"D*("`@
M("`@("`@("`@;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%35!]+R1B87-E
M;F%M921E>'0B.PH@("`@("`@("`@("!O=71S*")32$Q)0CH@)&9I;&5N86UE
M7&XB*3L*("`@("`@("`@("`@;W!E;B!M>2`D;W5T+"`G/B<L("1F:6QE;F%M
M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@
M("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@8VQO<V4@)&]U
M=#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1R97%U
M:7)E7VQI<W1[)&9U;&QN86UE?2`]"B`@("`@("`@("`@("1005(Z.DAE879Y
M.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PH@("`@("`@("`@("`@("`@
M8G5F(#T^("1B=68L"B`@("`@("`@("`@("`@("!C<F,@/3X@)&-R8RP*("`@
M("`@("`@("`@("`@(&YA;64@/3X@)&9U;&QN86UE+`H@("`@("`@("`@("!]
M.PH@("`@("`@('T*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('T*
M("`@(",@?7U]"@H@("`@;&]C86P@0$E.0R`]("AS=6(@>PH@("`@("`@(&UY
M("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*"B`@("`@("`@<F5T=7)N(&EF(')E
M9B`D;6]D=6QE(&]R("$D;6]D=6QE.PH*("`@("`@("!M>2`D9FEL96YA;64@
M/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["B`@("`@
M("`@("`@(&UY("1K97D["B`@("`@("`@("`@(&9O<F5A8V@@*&ME>7,@)7)E
M<75I<F5?;&ES="D@>PH@("`@("`@("`@("`@("`@;F5X="!U;FQE<W,@+UQ1
M)&UO9'5L95Q%)"\["B`@("`@("`@("`@("`@("`D:V5Y(#T@)%\[(&QA<W0[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@9&5L971E("1R97%U:7)E7VQI
M<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*("`@("`@("!](&]R(')E='5R
M;CL*"B`@("`@("`@)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M
M92\D;6]D=6QE(CL*"B`@("`@("`@:68@*"1%3E9[4$%27T-,14%.?2!A;F0@
M9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*("`@("`@("`@("`@;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*("`@("`@("`@
M("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!P<FEN="`D9F@@)&9I;&5N
M86UE+3Y[8G5F?3L*("`@("`@("`@("`@<V5E:R@D9F@L(#`L(#`I.PH@("`@
M("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*("`@("`@("!E;'-E('L*
M("`@("`@("`@("`@;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M
M)RP@)&9I;&5N86UE+3Y[8W)C?2D["B`@("`@("`@("`@(&EF("@D;W5T*2![
M"B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@
M("`@<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69].PH@("`@("`@("`@("`@
M("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!O<&5N
M(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I
M;FUO9&4H)&9H*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]
M"@H@("`@("`@(&1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F
M:6YD("1M;V1U;&4A7&XB.PH@("`@?2P@0$E.0RD["@H@("`@(R!.;W<@;&]A
M9"!A;&P@8G5N9&QE9"!F:6QE<R![>WL*"B`@("`C(&EN:71I86QI>F4@<VAA
M<F5D(&]B:F5C="!P<F]C97-S:6YG"B`@("!R97%U:7)E(%A33&]A9&5R.PH@
M("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!#87)P.CI(96%V
M>3L*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PH*("`@(",@;F]W(&QE="=S('1R>2!G
M971T:6YG(&AE;'!E<B!M;V1U;&5S(&9R;VT@=VET:&EN"B`@("!R97%U:7)E
M($E/.CI&:6QE.PH*("`@(",@;&]A9"!R97-T(&]F('1H92!G<F]U<"!I;@H@
M("`@=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?
M;&ES="E;,%TI('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?
M7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@('5N;&5S<R`H
M)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PH@
M("`@("`@("`@("`C(')E<75I<F4@;6]D=6QE<RP@9&\@;W1H97(@97AE8W5T
M86)L92!F:6QE<PH@("`@("`@("`@("!I9B`H)&9I;&5N86UE(#U^("]<+G!M
M8S\D+VDI('L*("`@("`@("`@("`@("`@(')E<75I<F4@)&9I;&5N86UE.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@
M("`@(R!3:VEP($%C=&EV95-T871E)W,@<VET96-U<W1O;6EZ92YP;"!F:6QE
M.@H@("`@("`@("`@("`@("`@9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA
M;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["B`@("`@("`@("`@('T*("`@
M("`@("!]"B`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE
M?3L*("`@('T*"B`@("`C('U]?0H*("`@(&QA<W0@=6YL97-S("1B=68@97$@
M(E!+7#`P,UPP,#0B.PH@("`@)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T
M.PI]"B,@?7U]"@HC($%R9W5M96YT('!R;V-E<W-I;F<@>WM["FUY($!P87)?
M87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I
M.PH*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%
M55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"@HD<75I970@/2`P('5N
M;&5S<R`D14Y6>U!!4E]$14)51WT["B,@1&]N)W0@<W=A;&QO=R!A<F=U;65N
M=',@9F]R(&-O;7!I;&5D(&5X96-U=&%B;&5S('=I=&AO=70@+2UP87(M;W!T
M:6]N<PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO
M<'1I;VYS)R`F)B!S:&EF="DI('L*("`@(&UY("5D:7-T7V-M9"`]('%W*`H@
M("`@("`@('`@("!B;&EB7W1O7W!A<@H@("`@("`@(&D@("!I;G-T86QL7W!A
M<@H@("`@("`@('4@("!U;FEN<W1A;&Q?<&%R"B`@("`@("`@<R`@('-I9VY?
M<&%R"B`@("`@("`@=B`@('9E<FEF>5]P87(*("`@("D["@H@("`@(R!I9B!T
M:&4@87!P(&ES(&EN=F]K960@87,@(F%P<&YA;64@+2UP87(M;W!T:6]N<R`M
M+7)E=7-E(%!23T=204T@0%!23T=?05)'5B(L"B`@("`C('5S92!T:&4@87!P
M('1O(')U;B!T:&4@9VEV96X@<&5R;"!C;V1E(&EN<W1E860@;V8@86YY=&AI
M;F<@9G)O;2!T:&4*("`@(",@87!P(&ET<V5L9B`H8G5T('-T:6QL('-E="!U
M<"!T:&4@;F]R;6%L(&%P<"!E;G9I<F]N;65N="!A;F0@0$E.0RD*("`@(&EF
M("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["B`@("`@("`@
M<VAI9G0@0$%21U8["B`@("`@("`@)$5.5GM005)?05!07U)%55-%?2`]('-H
M:69T($!!4D=6.PH@("`@?0H@("`@96QS92![(",@;F]R;6%L('!A<FP@8F5H
M879I;W5R"@H@("`@("`@(&UY($!A9&1?=&]?:6YC.PH@("`@("`@('=H:6QE
M("A`05)'5BD@>PH@("`@("`@("`@("`D05)'5ELP72`]?B`O7BTH6T%)34]"
M3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PH*("`@("`@("`@("`@:68@*"0Q
M(&5Q("=))RD@>PH@("`@("`@("`@("`@("`@<'5S:"!`861D7W1O7VEN8RP@
M)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=-
M)RD@>PH@("`@("`@("`@("`@("`@979A;"`B=7-E("0R(CL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T$G*2!["B`@("`@("`@
M("`@("`@("!U;G-H:69T($!P87)?87)G<RP@)#(["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=/)RD@>PH@("`@("`@("`@("`@
M("`@)&]U="`]("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF
M("@D,2!E<2`G8B<I('L*("`@("`@("`@("`@("`@("1B=6YD;&4@/2`G<VET
M92<["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("="
M)RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]("=A;&PG.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G<2<I('L*("`@("`@
M("`@("`@("`@("1Q=6EE="`](#$["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@96QS:68@*"0Q(&5Q("=,)RD@>PH@("`@("`@("`@("`@("`@;W!E;B`D
M;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z
M("0A(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@
M)U0G*2!["B`@("`@("`@("`@("`@("`D8V%C:&5?;F%M92`]("0R.PH@("`@
M("`@("`@("!]"@H@("`@("`@("`@("!S:&EF="A`05)'5BD["@H@("`@("`@
M("`@("!I9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*("`@("`@("`@
M("`@("`@(&1E;&5T92`D14Y6>R=005)?5$5-4"=].PH@("`@("`@("`@("`@
M("`@:6YI=%]I;F,H*3L*("`@("`@("`@("`@("`@(')E<75I<F4@4$%2.CI$
M:7-T.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U
M;FQE<W,@0$%21U8["B`@("`@("`@("`@("`@("`F>R)005(Z.D1I<W0Z.B1C
M;60B?2@D7RD@9F]R($!!4D=6.PH@("`@("`@("`@("`@("`@97AI=#L*("`@
M("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@=6YS:&EF="!`24Y#+"!`
M861D7W1O7VEN8SL*("`@('T*?0H*(R!86%@@+2T@861D("TM<&%R+61E8G5G
M('-U<'!O<G0A"@HC('U]?0H*(R!/=71P=70@;6]D92`H+4\I(&AA;F1L:6YG
M('M[>PII9B`H)&]U="D@>PH@("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#
M=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@
M("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z
M.EII<#L*("`@('T*"B`@("!M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PH@("`@
M;7D@)'II<#L*"@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P
M96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A
M<B<Z("0A(CL*("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@8FQE<W,H
M)&9H+"`G24\Z.D9I;&4G*3L*"B`@("`@("`@)'II<"`]($%R8VAI=F4Z.EII
M<"T^;F5W.PH@("`@("`@("@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*("`@("`@("`@
M("`@;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PH@("`@?0H*"B`@
M("!M>2`E96YV(#T@9&\@>PH@("`@("`@(&EF("@D>FEP(&%N9"!M>2`D;65T
M82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B`@("`@("`@("`@
M("1M971A(#U^(',O+BI><&%R.B0O+VUS.PH@("`@("`@("`@("`D;65T82`]
M?B!S+UY<4RXJ+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@+UX@("A;7CI=
M*RDZ("@N*RDD+VUG.PH@("`@("`@('T*("`@('T["@H@("`@(R!/<&5N(&EN
M<'5T(&%N9"!O=71P=70@9FEL97,@>WM["B`@("!L;V-A;"`D+R`](%PT.PH*
M("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(%!!4BP@)SPG
M+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PH@("`@("`@(&)I;FUO9&4H4$%2
M*3L*("`@("`@("!D:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S
M<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["B`@("!]"@H@("`@0W)E871E4&%T
M:"@D;W5T*2`["B`@("`*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<H"B`@
M("`@("`@)&]U="P*("`@("`@("!)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z
M.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`H@("`@
M("`@(#`W-S<L"B`@("`I(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H*3L*
M"B`@("`D+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@
M=6YD968["B`@("!S965K(%]&2"P@,"P@,#L*("`@(&UY("1L;V%D97(@/2!S
M8V%L87(@/%]&2#X["B`@("!I9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*("`@("`@("!R97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@("`@("!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0H@("`@?0H@("`@
M9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PH@("`@("`@(&UY
M("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B`@("`@("`@)'9A;"`](&5V
M86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["B`@("`@("`@;7D@)&UA9VEC
M(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PH@("`@("`@(&UY
M("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B`@("`@("`@
M)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PH@("`@("`@("`@("`D;6%G:6,@
M+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*
M("`@("`@("!]96<["B`@("!]"B`@("`D9F@M/G!R:6YT*"1L;V%D97(I.PH@
M("`@)"\@/2!U;F1E9CL*("`@(",@?7U]"@H@("`@(R!7<FET92!B=6YD;&5D
M(&UO9'5L97,@>WM["B`@("!I9B`H)&)U;F1L92D@>PH@("`@("`@(')E<75I
M<F4@4$%2.CI(96%V>3L*("`@("`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["B`@("`@("`@:6YI=%]I;F,H*3L*"B`@("`@("`@<F5Q=6ER
M95]M;V1U;&5S*"D["@H@("`@("`@(&UY($!I;F,@/2!S;W)T('L*("`@("`@
M("`@("`@;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0H@("`@("`@('T@9W)E
M<"!["B`@("`@("`@("`@("$O0E-$4$%.+PH@("`@("`@('T@9W)E<"!["B`@
M("`@("`@("`@("@D8G5N9&QE(&YE("=S:71E)RD@;W(*("`@("`@("`@("`@
M*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*("`@("`@
M("`@("`@("1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["B`@
M("`@("`@?2!`24Y#.PH*("`@("`@("`C($9I;&4@97AI<W1S('1E<W0@861D
M960@=&\@9FEX(%)4(",T,3<Y,#H*("`@("`@("`C($9U;FYY+"!N;VXM97AI
M<W1I;F<@96YT<GD@:6X@7SPN+BXN875T;R]#;VUP<F5S<R]287<O6FQI8B]A
M=71O<W!L:70N:7@N"B`@("`@("`@(R!4:&ES(&ES(&$@8F%N9"UA:60@9FEX
M('=I=&@@;F\@9&5E<&5R(&=R87-P(&]F('1H92!I<W-U92X*("`@("`@("`C
M(%-O;65B;V1Y('!L96%S92!G;R!T:')O=6=H('1H92!P86EN(&]F('5N9&5R
M<W1A;F1I;F<@=VAA="=S(&AA<'!E;FEN9RP*("`@("`@("`C($D@9F%I;&5D
M+B`M+2!3=&5F9F5N"B`@("`@("`@;7D@)69I;&5S.PH@("`@("`@("]>7SPH
M+BLI)"\@86YD("UE("0Q(&%N9"`D9FEL97-[)#%]*RL@9F]R(&ME>7,@)3HZ
M.PH@("`@("`@("1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)3D,["@H@("`@
M("`@(&UY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PH@
M("`@("`@(&UY("5W<FET=&5N.PH*("`@("`@("!F;W)E86-H("AS;W)T(&ME
M>7,@)69I;&5S*2!["B`@("`@("`@("`@(&UY("@D;F%M92P@)&9I;&4I.PH*
M("`@("`@("`@("`@9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["B`@("`@("`@
M("`@("`@("!I9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1?
M?2D@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE(#T@)%\["B`@("`@("`@
M("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI('L*
M("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D,2P@)#(I
M.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!E;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;
M7D-C72E<6B$I('L*("`@("`@("`@("`@("`@("`@("!I9B`H;7D@)')E9B`]
M("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L*("`@("`@("`@("`@
M("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PH@("`@
M("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@("`@
M('T*("`@("`@("`@("`@("`@("`@("!E;'-I9B`H+68@(B1D:7(O)#$B*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"(D
M9&ER+R0Q(BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@
M("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@?0H*("`@("`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M
M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PH@("`@("`@("`@("!N97AT
M(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D
M+SL*("`@("`@("`@("`@;W5T<R@@:F]I;B`B(BP*("`@("`@("`@("`@("`@
M('%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D
M9FEL92P*("`@("`@("`@("`@("`@('%Q*"(N+BXI"B`@("`@("`@("`@("D[
M"@H@("`@("`@("`@("!M>2`D8V]N=&5N=#L*("`@("`@("`@("`@:68@*')E
M9B@D9FEL92DI('L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@)&9I;&4M
M/GMB=69].PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("`@("`@;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N
M)W0@;W!E;B`D9FEL93H@)"$B.PH@("`@("`@("`@("`@("`@8FEN;6]D92A&
M24Q%*3L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@/$9)3$4^.PH@("`@
M("`@("`@("`@("`@8VQO<V4@1DE,13L*"B`@("`@("`@("`@("`@("!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL
M92D*("`@("`@("`@("`@("`@("`@("!I9B`A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["@H@("`@("`@("`@
M("`@("`@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<
M)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(&]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B`@("`@("`@
M("`@("1F:"T^<')I;G0H(D9)3$4B*3L*("`@("`@("`@("`@)&9H+3YP<FEN
M="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI*3L*("`@("`@("`@("`@
M)&9H+3YP<FEN="AS<')I;G1F*`H@("`@("`@("`@("`@("`@(B4P.'@O)7,B
M+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE
M"B`@("`@("`@("`@("DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH
M)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B`@("`@("`@("`@("1F:"T^<')I
M;G0H)&-O;G1E;G0I.PH@("`@("`@('T*("`@('T*("`@(",@?7U]"@H@("`@
M(R!.;W<@=W)I=&4@;W5T('1H92!005(@86YD(&UA9VEC('-T<FEN9W,@>WM[
M"B`@("`D>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["@H@
M("`@)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PH@
M("`@:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U
M="DI6SE=*2!["B`@("`@("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M
M/FYE=R!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@(",@5V]R:V%R;W5N
M9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@
M("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)3
M24].('T@?'P@,#L*("`@("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X
M)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@("1C
M='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@?0H@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM
M>2`D9F@L("(\)&]U="(I*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1F
M:"D["B`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@
M("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H*("`@("`@("`D8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E
M<W0@.B`D;71I;64["B`@("!]"B`@("`D8V%C:&5?;F%M92`N/2`B7#`B('@@
M*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*("`@("1C86-H95]N86UE("X]
M(")#04-(12(["B`@("`D9F@M/G!R:6YT*"1C86-H95]N86UE*3L*("`@("1F
M:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R
M*2DI.PH@("`@)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PH@("`@)&9H+3YC
M;&]S93L*("`@(&-H;6]D(#`W-34L("1O=70["B`@("`C('U]?0H*("`@(&5X
M:70["GT*(R!]?7T*"B,@4')E<&%R92`D<')O9VYA;64@:6YT;R!005(@9FEL
M92!C86-H92![>WL*>PH@("`@;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?
M<&]S.PH*("`@(%]F:7A?<')O9VYA;64H*3L*"B`@("`C($YO=R!L;V%D('1H
M92!005(@9FEL92!A;F0@<'5T(&ET(&EN=&\@4$%2.CI,:6)#86-H92![>WL*
M("`@(')E<75I<F4@4$%2.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PH*"B`@("!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=]
M(#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U
M:7)E($9I;&4Z.D9I;F0["B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`[
M"B`@("!]"B`@("!M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("!M
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PH@("`@)&9H+3YF9&]P96XH9FEL96YO
M*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PH@("`@)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PH*("`@('!U<V@@0%!!4CHZ3&EB
M0V%C:&4L("1Z:7`["B`@("`D4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@
M)'II<#L*"B`@("`D<75I970@/2`A)$5.5GM005)?1$5"54=].PH@("`@;W5T
M<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["@H@
M("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@
M<V5T(&%T('1H:7,@<&]I;G0A"B`@("`@("`@9F]R96%C:"!M>2`D;65M8F5R
M("@@)'II<"T^;65M8F5R<R`I('L*("`@("`@("`@("`@;F5X="!I9B`D;65M
M8F5R+3YI<T1I<F5C=&]R>3L*("`@("`@("`@("`@;7D@)&UE;6)E<E]N86UE
M(#T@)&UE;6)E<BT^9FEL94YA;64["B`@("`@("`@("`@(&YE>'0@=6YL97-S
M("1M96UB97)?;F%M92`]?B!M>PH@("`@("`@("`@("`@("`@7@H@("`@("`@
M("`@("`@("`@+S]S:&QI8B\*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z
M.D-O;F9I9WMV97)S:6]N?2\I/PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PH@("`@("`@("`@("`@("`@*%M>+UTK
M*0H@("`@("`@("`@("`@("`@)`H@("`@("`@("`@("!]>#L*("`@("`@("`@
M("`@;7D@)&5X=')A8W1?;F%M92`]("0Q.PH@("`@("`@("`@("!M>2`D9&5S
M=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@
M)&5X=')A8W1?;F%M92D["B`@("`@("`@("`@(&EF("@M9B`D9&5S=%]N86UE
M("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["B`@
M("`@("`@("`@("`@("!O=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B
M('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PH@
M("`@("`@("`@("!](&5L<V4@>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A%
M>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PH@
M("`@("`@("`@("`@("`@)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D
M97-T7VYA;64I.PH@("`@("`@("`@("`@("`@8VAM;V0H,#4U-2P@)&1E<W1?
M;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*("`@("`@("`@("`@?0H@("`@("`@
M('T*("`@('T*("`@(",@?7U]"GT*(R!]?7T*"B,@268@=&AE<F4G<R!N;R!M
M86EN+G!L('1O(')U;BP@<VAO=R!U<V%G92![>WL*=6YL97-S("@D4$%2.CI,
M:6)#86-H97LD<')O9VYA;65]*2!["B`@("!D:64@/#P@(BXB('5N;&5S<R!`
M05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM
M;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70H@("`@("`@)#`@
M6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@H@("`@)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*
M(R!]?7T*"G-U8B!#<F5A=&50871H('L*("`@(&UY("@D;F%M92D@/2!`7SL*
M("`@(`H@("`@<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*("`@(&UY("@D8F%S
M96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R
M<V4H)&YA;64L("@G7"XN*B<I*3L*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI0
M871H.PH@("`@"B`@("!&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S
M<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"@IS=6(@
M<F5Q=6ER95]M;V1U;&5S('L*("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`]
M(%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["@H@("`@<F5Q=6ER92!L
M:6(["B`@("!R97%U:7)E($1Y;F%,;V%D97(["B`@("!R97%U:7)E(&EN=&5G
M97(["B`@("!R97%U:7)E('-T<FEC=#L*("`@(')E<75I<F4@=V%R;FEN9W,[
M"B`@("!R97%U:7)E('9A<G,["B`@("!R97%U:7)E($-A<G`["B`@("!R97%U
M:7)E($-A<G`Z.DAE879Y.PH@("`@<F5Q=6ER92!%<G)N;SL*("`@(')E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CL*("`@
M(')E<75I<F4@1F-N=&P["B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R
M97%U:7)E($9I;&4Z.E-P96,["B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@
M<F5Q=6ER92!#;VYF:6<["B`@("!R97%U:7)E($E/.CI(86YD;&4["B`@("!R
M97%U:7)E($E/.CI&:6QE.PH@("`@<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*
M("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@<F5Q=6ER92!005(["B`@
M("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E(%!!4CHZ1&ES=#L*
M("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PH@("`@<F5Q=6ER92!A='1R
M:6)U=&5S.PH@("`@979A;"![(')E<75I<F4@0W=D('T["B`@("!E=F%L('L@
M<F5Q=6ER92!7:6XS,B!].PH@("`@979A;"![(')E<75I<F4@4V-A;&%R.CI5
M=&EL('T["B`@("!E=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R
M<W0@?3L*("`@(&5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T
M=7)E('T["B`@("!E=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R
M;$E/.CIS8V%L87(@?3L*?0H*(R!4:&4@0R!V97)S:6]N(&]F('1H:7,@8V]D
M92!A<'!E87)S(&EN(&UY;&1R+VUK=&UP9&ER+F,*(R!4:&ES(&-O9&4@86QS
M;R!L:79E<R!I;B!005(Z.E-E='5P5&5M<"!A<R!S971?<&%R7W1E;7!?96YV
M(0IS=6(@7W-E=%]P87)?=&5M<"!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B`@("`@
M("`@)'!A<E]T96UP(#T@)#$["B`@("`@("`@<F5T=7)N.PH@("`@?0H*("`@
M(&9O<F5A8V@@;7D@)'!A=&@@*`H@("`@("`@("AM87`@)$5.5GLD7WTL('%W
M*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`H@("`@
M("`@('%W*"!#.EQ<5$5-4"`O=&UP("X@*0H@("`@*2!["B`@("`@("`@;F5X
M="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P
M871H.PH@("`@("`@(&UY("1U<V5R;F%M93L*("`@("`@("!M>2`D<'=U:60[
M"B`@("`@("`@(R!D;V5S(&YO="!W;W)K(&5V97)Y=VAE<F4Z"B`@("`@("`@
M979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM]
M.PH*("`@("`@("!I9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@
M>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*
M("`@("`@("!]"B`@("`@("`@96QS:68@*&1E9FEN960@)'!W=6ED*2!["B`@
M("`@("`@("`@("1U<V5R;F%M92`]("1P=W5I9#L*("`@("`@("!]"B`@("`@
M("`@96QS92!["B`@("`@("`@("`@("1U<V5R;F%M92`]("1%3E9[55-%4DY!
M345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["B`@("`@("`@?0H@("`@
M("`@("1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*"B`@("`@("`@;7D@)'-T;7!D
M:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M)'5S97)N86UE(CL*("`@
M("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!I9B`H(21%3E9[
M4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;
M.5TI('L*("`@("`@("`@("`@;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M
M92D["B`@("`@("`@("`@('-E96L@)&9H+"`M,3@L(#(["B`@("`@("`@("`@
M('-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PH@("`@("`@("`@("!I9B`H)&)U
M9B!E<2`B7#!#04-(12(I('L*("`@("`@("`@("`@("`@('-E96L@)&9H+"`M
M-3@L(#(["B`@("`@("`@("`@("`@("!S>7-R96%D("1F:"P@)&)U9BP@-#$[
M"B`@("`@("`@("`@("`@("`D8G5F(#U^(',O7#`O+V<["B`@("`@("`@("`@
M("`@("`D<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B
M=68["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@
M("`@("`@("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[
M($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("`@("`@("`@('Q\
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN
M97<@?0H@("`@("`@("`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["@H@("`@("`@("`@("`@
M("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A
M;F0@-2XS.0H@("`@("`@("`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A
M;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@("`@
M("`@("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I
M;VX@97$@)S4N,SDG*2!["B`@("`@("`@("`@("`@("`@("`@)&-T>"T^861D
M9FEL92@D<')O9VYA;64L(")B(BD@:68@*"1C='@I.PH@("`@("`@("`@("`@
M("`@?0H@("`@("`@("`@("`@("`@96QS92!["B`@("`@("`@("`@("`@("`@
M("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2![
M"B`@("`@("`@("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@
M("`@("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@
M("`@("`@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@('T*"B`@("`@("`@("`@("`@("`D<W1M
M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C
M='@M/FAE>&1I9V5S="`Z("1M=&EM92`I.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@
M("`@("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`Q.PH@("`@("`@("`@("`D
M<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["B`@("`@("`@
M?0H*("`@("`@("`D14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PH@("`@("`@
M(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&QA<W0["B`@("!]"@H@
M("`@)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[
M4$%27U1%35!](#U^("\H+BLI+SL*?0H*<W5B(%]T96UP9FEL92!["B`@("!M
M>2`H)&5X="P@)&-R8RD@/2!`7SL*("`@(&UY("@D9F@L("1F:6QE;F%M92D[
M"@H@("`@)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["@H@("`@
M:68@*"1%3E9[4$%27T-,14%.?2D@>PH@("`@("`@('5N;&EN:R`D9FEL96YA
M;64@:68@+64@)&9I;&5N86UE.PH@("`@("`@('!U<V@@0'1M<&9I;&4L("1F
M:6QE;F%M93L*("`@('T*("`@(&5L<V4@>PH@("`@("`@(')E='5R;B`H=6YD
M968L("1F:6QE;F%M92D@:68@*"UR("1F:6QE;F%M92D["B`@("!]"@H@("`@
M;W!E;B`D9F@L("<^)RP@)&9I;&5N86UE(&]R(&1I92`D(3L*("`@(&)I;FUO
M9&4H)&9H*3L*("`@(')E='5R;B@D9F@L("1F:6QE;F%M92D["GT*"B,@<V%M
M92!C;V1E(&QI=F5S(&EN(%!!4CHZ4V5T=7!0<F]G;F%M93HZ<V5T7W!R;V=N
M86UE"G-U8B!?<V5T7W!R;V=N86UE('L*("`@(&EF("AD969I;F5D("1%3E9[
M4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI
M+RD@>PH@("`@("`@("1P<F]G;F%M92`]("0Q.PH@("`@?0H*("`@("1P<F]G
M;F%M92!\?#T@)#`["@H@("`@:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E
M>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B`@("`@("`@
M)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PH@("`@?0H*("`@(&EF("@A)$5.
M5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?
M9&5L:6U]*2`^/2`P*2!["B`@("`@("`@:68@*&]P96X@;7D@)&9H+"`G/"<L
M("1P<F]G;F%M92D@>PH@("`@("`@("`@("!R971U<FX@:68@+7,@)&9H.PH@
M("`@("`@('T*("`@("`@("!I9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X
M97TB*2!["B`@("`@("`@("`@("1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5]
M.PH@("`@("`@("`@("!R971U<FX["B`@("`@("`@?0H@("`@?0H*("`@(&9O
M<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H7W-E<'U<12\L
M("1%3E9[4$%42'TI('L*("`@("`@("!N97AT(&EF(&5X:7-T<R`D14Y6>U!!
M4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*("`@("`@("`D
M9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL*("`@("`@("`H*"1P
M<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I
M9WM?97AE?2(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB.PH@("`@("`@("@H
M)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@
M;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64B.PH@("`@?0I]"@IS=6(@7V9I>%]P<F]G;F%M92!["B`@("`D
M,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PH@("`@:68@
M*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*("`@
M("`@("`D<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92([
M"B`@("!]"@H@("`@(R!86%@@+2!H86-K('1O(&UA:V4@4%=$('=O<FL*("`@
M(&UY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C
M=V0H*0H@("`@("`@("`@("`@("`@.B`H*&1E9FEN960@)E=I;C,R.CI'971#
M=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PH@("`@8VAO;7`H)'!W
M9"D["B`@("`D<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E
M;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*"B`@("`D14Y6>U!!4E]0
M4D]'3D%-17T@/2`D<')O9VYA;64["GT*"G-U8B!?<&%R7VEN:71?96YV('L*
M("`@(&EF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*("`@
M("`@("!R971U<FX["B`@("!](&5L<V4@>PH@("`@("`@("1%3E9[4$%27TE.
M251)04Q)6D5$?2`](#(["B`@("!]"@H@("`@9F]R("AQ=R@@4U!!5TY%1"!4
M14U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'5E\P("D@
M*2!["B`@("`@("`@9&5L971E("1%3E9[)U!!4E\G+B1??3L*("`@('T*("`@
M(&9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*("`@("`@
M("`D14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF
M(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PH@("`@?0H*("`@(&UY
M("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@
M("`B.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2D@>PH@("`@("`@(&1E;&5T
M92`D14Y6>U!!4E]#3$5!3GT["B`@("!]"B`@("!E;'-I9B`H(65X:7-T<R`D
M14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["B`@("`@("`@;7D@)'9A;'5E(#T@
M<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*("`@
M("`@("`D14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?
M0TQ%04X]*%Q3*RDO.PH@("`@?0I]"@IS=6(@;W5T<R!["B`@("!R971U<FX@
M:68@)'%U:65T.PH@("`@:68@*"1L;V=F:"D@>PH@("`@("`@('!R:6YT("1L
M;V=F:"`B0%]<;B(["B`@("!]"B`@("!E;'-E('L*("`@("`@("!P<FEN="`B
M0%]<;B(["B`@("!]"GT*"G-U8B!I;FET7VEN8R!["B`@("!R97%U:7)E($-O
M;F9I9SL*("`@('!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I
M9SHZ0V]N9FEG>R1??2P@<7<H"B`@("`@("`@87)C:&QI8F5X<"!P<FEV;&EB
M97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*("`@("`@("!V96YD;W)A<F-H
M97AP('9E;F1O<FQI8F5X<`H@("`@*3L*?0H*(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C"B,@5&AE(&UA:6X@<&%C:V%G92!F;W(@<V-R:7!T(&5X96-U
M=&EO;@H*<&%C:V%G92!M86EN.PH*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.
M0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PH*
M9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N
M86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0H@("`@=6YL97-S
M("UE("1P<F]G;F%M93L*"F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@
M:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`
M.PH*?3L*"B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0H*0T]213HZ97AI="@D
M,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID
M:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PH*,3L*"B-L:6YE(#$P,3$*
M"E]?14Y$7U\*`````/____\`)$9R965"4T0Z('-R8R]L:6(O8W-U+W-P87)C
M-C0O8W)T,2YC+'8@,2XQ.2XR+C$@,C`Q,2\P.2\R,R`P,#HU,3HS-R!K96YS
M;6ET:"!%>'`@)``D1G)E94)31#H@<W)C+VQI8B]C<W4O8V]M;6]N+V-R=&)R
M86YD+F,L=B`Q+C<N,BXQ(#(P,3$O,#DO,C,@,#`Z-3$Z,S<@:V5N<VUI=&@@
M17AP("0`1T-#.B`H1TY5*2`T+C(N,B`R,#`W,#@S,2!P<F5R96QE87-E(%M&
M<F5E0E-$70``)$9R965"4T0Z('-R8R]L:6(O8W-U+W-P87)C-C0O8W)T:2Y3
M+'8@,2XR+C(N,2`R,#$Q+S`Y+S(S(#`P.C4Q.C,W(&ME;G-M:71H($5X<"`D
M``!'0T,Z("A'3E4I(#0N,BXR(#(P,#<P.#,Q('!R97)E;&5A<V4@6T9R965"
M4T1=``!'0T,Z("A'3E4I(#0N,BXR(#(P,#<P.#,Q('!R97)E;&5A<V4@6T9R
M965"4T1=``!'0T,Z("A'3E4I(#0N,BXR(#(P,#<P.#,Q('!R97)E;&5A<V4@
M6T9R965"4T1=```D1G)E94)31#H@<W)C+VQI8B]C<W4O<W!A<F,V-"]C<G1N
M+E,L=B`Q+C(N,BXQ(#(P,3$O,#DO,C,@,#`Z-3$Z,S<@:V5N<VUI=&@@17AP
M("0``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+FAA<V@`+F1Y
M;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L
M82YD>6X`+G)E;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H
M7V9R86UE`"YC=&]R<P`N9'1O<G,`+FIC<@`N9'EN86UI8P`N9V]T`"YD871A
M`"YB<W,`+F-O;6UE;G0`````````````````````````````````````````
M````````````````````````````````````````````````````"P````$`
M`````````@``````$`&0`````````9``````````%0``````````````````
M``$``````````````!,````'``````````(``````!`!J`````````&H````
M`````!@````````````````````$```````````````A````!0`````````"
M```````0`<`````````!P`````````,L````!```````````````"```````
M```$````)P````L``````````@``````$`3P````````!/`````````)P```
M``4````!``````````@`````````&````"\````#``````````(``````!`.
ML`````````ZP````````!-$````````````````````!```````````````W
M;____P`````````"```````0$X(````````3@@````````#0````!```````
M`````````@`````````"````1&____X``````````@``````$!18````````
M%%@`````````4`````4````"``````````@``````````````%,````$````
M``````(``````!`4J````````!2H`````````8`````$```````````````(
M`````````!@```!=````!``````````"```````0%B@````````6*```````
M``6X````!````!0`````````"``````````8````9P````$`````````!@``
M````$!O@````````&^``````````'`````````````````````0`````````
M`````&T````!``````````8``````!`<`````````!P`````````.B``````
M```````````````@``````````````!S`````0`````````&```````05B``
M``````!6(``````````4````````````````````!```````````````>0``
M``$``````````@``````$%8X````````5C@````````$<```````````````
M``````@``````````````($````!``````````(``````!!:J````````%JH
M``````````0````````````````````$``````````````"+`````0``````
M```#```````@8`````````!@```````````0````````````````````"```
M````````````D@````$``````````P``````(&`0````````8!``````````
M$`````````````````````@``````````````)D````!``````````,`````
M`"!@(````````&`@``````````@````````````````````(````````````
M``">````!@`````````#```````@8"@```````!@*`````````(0````!0``
M````````````"``````````0````IP````$``````````P``````(&(X````
M````8C@`````````"`````````````````````@`````````"````&(````!
M``````````<``````"!C`````````&,`````````""``````````````````
M``$``````````"````"L`````0`````````#```````@:R````````!K(```
M`````%O`````````````````````"```````````````L@````@`````````
M`P``````(,;@````````QN`````````$^`````````````````````@`````
M`````````+<````!`````````````````````````````,;@`````````@X`
M```````````````````!```````````````!`````P``````````````````
J``````````#([@````````#``````````````````````0``````````
